@@ -13,6 +13,10 @@
 #ifndef DISPLAY_H
 #define DISPLAY_H
 
+
+#define DISPLAY_LOADING_ANIMATE_TIME 250
+
+
 void display_register_widgets(UIData *ui);
 
 void display_freeze(void);
@@ -54,6 +58,8 @@ void display_set_io_information(gint zero);
 void display_set_song_text_info(gint n, gint current);
 void display_set_title(const gchar *text);
 
+void display_set_playlist(const gchar *text);
+
 void display_set_song_info(void);
 
 
