@@ -126,7 +126,7 @@ gint		change_delay = 0;
 gint		flyby_enabled = FALSE;
 gint		flyby_location = 3;
 
-gint 		skinned_menus_enable = FALSE;
+gint		skinned_menus_enable = FALSE;
 
 /* end of globals */
 
@@ -148,12 +148,6 @@ void init_vars(void)
 		preset_file[i] = NULL;
 		}
 
-	window_list_columns = g_strdup("160, 100, 100, 30, 30, 60, 160, 160");
+	window_list_columns = g_strdup("");
 }
 
-
-
-
-
-
-
