@@ -446,7 +446,7 @@ static void pipe_reader_shutdown(void)
 	if (mpg123_data_check_id != -1) gtk_timeout_remove(mpg123_data_check_id);
 	mpg123_data_check_id = -1;
 
-	if (mpg123_pipe_read_id != -1) gtk_input_remove(mpg123_pipe_read_id);
+	if (mpg123_pipe_read_id != -1) g_source_remove(mpg123_pipe_read_id);
 	mpg123_pipe_read_id = -1;
 
 	close(mpg123_pipe[0]);
@@ -570,7 +570,7 @@ static void mpg123_data_check_update(gint secs)
 static char mpg123_read_buffer[1024];
 static gint mpg123_read_buffer_pos = 0;
 
-static void mpg123_pipe_read_cb(gpointer data, int fd, GdkInputCondition condition)
+static gboolean mpg123_pipe_read_cb(GIOChannel *source, GIOCondition condition, gpointer data)
 {
 	gint is_http = GPOINTER_TO_INT(data);
 	gchar buf[1024];
@@ -582,23 +582,23 @@ static void mpg123_pipe_read_cb(gpointer data, int fd, GdkInputCondition conditi
 	if (status != STATUS_PLAY)
 		{
 		pipe_reader_shutdown();
-		return;
+		return TRUE;
 		}
 
-	r = read(fd, buf, sizeof(buf));
+	r = read(mpg123_pipe[0], buf, sizeof(buf));
 
 	if (debug_mode > 2) printf("mpg123 read input %d bytes\n", r);
 
 	if (r == -1)
 		{
 		handle_read_error();
-		return;
+		return TRUE;
 		}
 
 	if (r == 0)
 		{
 		handle_end_of_file();
-		return;
+		return TRUE;
                 }
 
 	ptr = mpg123_read_buffer + mpg123_read_buffer_pos;
@@ -615,11 +615,11 @@ static void mpg123_pipe_read_cb(gpointer data, int fd, GdkInputCondition conditi
 			if (mpg123_read_buffer_pos > 0)
 				{
 				mpg123_read_buffer[mpg123_read_buffer_pos] = '\0';
-				if (parse_pipe_buffer(mpg123_read_buffer) == -1) return;
+				if (parse_pipe_buffer(mpg123_read_buffer) == -1) return TRUE;
 				if (status == STATUS_NEXT)
 					{
 					pipe_reader_shutdown();
-					return;
+					return TRUE;
 					}
 				mpg123_read_buffer_pos = 0;
 				}
@@ -637,6 +637,8 @@ static void mpg123_pipe_read_cb(gpointer data, int fd, GdkInputCondition conditi
 	 * NOTE: 20 seconds (132 times) for http.
 	 */
 	mpg123_data_check_update((is_http) ? 20 : 10);
+
+	return TRUE;
 }
 
 static void mpg123_input_read_reset(void)
@@ -655,6 +657,7 @@ static gint start_playing_file(SongData *sd, gint position)
 	int cmd_cnt = 0;
 	gint start_frame;
 	gchar *exec_bin = MPG123_BINARY;
+	GIOChannel *channel;
 
 	cmd_max = sizeof(cmd_arguments) / MPG123_MAX_COMMANDS;
 
@@ -882,8 +885,14 @@ static gint start_playing_file(SongData *sd, gint position)
 	if (debug_mode) printf("mpg123 pid = %d\n", pid);
 
 	mpg123_input_read_reset();
+	channel = g_io_channel_unix_new(mpg123_pipe[0]);
+	mpg123_pipe_read_id = g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, G_IO_IN,
+			      mpg123_pipe_read_cb, GINT_TO_POINTER(mpg123_extra_is_http(sd)), NULL);
+	g_io_channel_unref(channel);
+#if 0
 	mpg123_pipe_read_id = gdk_input_add(mpg123_pipe[0], GDK_INPUT_READ,
 					    mpg123_pipe_read_cb, GINT_TO_POINTER(mpg123_extra_is_http(sd)));
+#endif
 
 	return TRUE;
 }
