@@ -485,7 +485,7 @@ gint ogg123_comment_set(const gchar *path, GList *comments)
 					"GQmpeg", "warning", TRUE, NULL, NULL);
 		g_free(msg);
 
-	        generic_dialog_add(gd, _("Ok"), NULL, TRUE);
+	        generic_dialog_add_stock(gd, NULL, GTK_STOCK_OK, NULL, TRUE);
 
 		tw = gtk_text_view_new();
 		gtk_widget_set_size_request(tw, 400, 200);
@@ -608,7 +608,7 @@ static void ogg123_child_shutdown(void)
 		if (t != ogg123_child_pid && t != -1) waitpid(ogg123_child_pid, NULL, 0);
 		}
 
-	if (ogg123_control_read_id != -1) gdk_input_remove(ogg123_control_read_id);
+	if (ogg123_control_read_id != -1) g_source_remove(ogg123_control_read_id);
 	ogg123_control_read_id = -1;
 	close(ogg123_pipe[0]);
 	ogg123_pipe[0] = -1;
@@ -781,7 +781,7 @@ static gint ogg123_input_parse(const gchar *buffer)
 static char ogg123_read_buffer[1024];
 static gint ogg123_read_buffer_pos = 0;
 
-static void ogg123_input_read_cb(gpointer data, int fd, GdkInputCondition condition)
+static gboolean ogg123_input_read_cb(GIOChannel *source, GIOCondition condition, gpointer data)
 {
 	gchar buf[1024];
 	gint r;
@@ -789,19 +789,19 @@ static void ogg123_input_read_cb(gpointer data, int fd, GdkInputCondition condit
 	gint l;
 	gchar *ptr;
 
-	r = read(fd, buf, sizeof(buf));
+	r = read(ogg123_pipe[0], buf, sizeof(buf));
 
 	if (r == -1)
 		{
 		ogg123_input_error();
-		return;
+		return TRUE;
 		}
 	if (r == 0)
 		{
 		printf(_("ogg123 disappeared! (unexpected EOF)\n"));
 		ogg123_input_end();
 		ogg123_error();
-		return;
+		return TRUE;
 		}
 
 	ptr = ogg123_read_buffer + ogg123_read_buffer_pos;
@@ -822,7 +822,7 @@ static void ogg123_input_read_cb(gpointer data, int fd, GdkInputCondition condit
  			if (ogg123_read_buffer_pos > 0)
 				{
 				ogg123_read_buffer[ogg123_read_buffer_pos] = '\0';
-				if (!ogg123_input_parse(ogg123_read_buffer)) return;
+				if (!ogg123_input_parse(ogg123_read_buffer)) return TRUE;
 				ogg123_read_buffer_pos = 0;
 				}
 			}
@@ -841,6 +841,8 @@ static void ogg123_input_read_cb(gpointer data, int fd, GdkInputCondition condit
 		ogg123_input_parse(ogg123_read_buffer);
 		}
 #endif
+
+	return TRUE;
 }
 
 static void ogg123_input_read_reset(void)
@@ -862,6 +864,7 @@ static gint ogg123_child_run(SongData *sd, gint position)
 	char *cmd_ptr[OGG123_MAX_COMMANDS];
 	int cmd_cnt = 0;
 	size_t cmd_max;
+	GIOChannel *channel;
 
 	cmd_max = sizeof(cmd_arguments) / OGG123_MAX_COMMANDS;
 
@@ -936,7 +939,15 @@ static gint ogg123_child_run(SongData *sd, gint position)
 	pid = ogg123_child_pid;
 
 	ogg123_input_read_reset();
+
+	channel = g_io_channel_unix_new(ogg123_pipe[0]);
+	ogg123_control_read_id = g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, G_IO_IN,
+						     ogg123_input_read_cb, NULL, NULL);
+	g_io_channel_unref(channel);
+
+#if 0
 	ogg123_control_read_id = gdk_input_add (ogg123_pipe[0], GDK_INPUT_READ, ogg123_input_read_cb, NULL);
+#endif
 
 	return TRUE;
 }
