@@ -106,10 +106,10 @@ GtkWidget *radio_config_init(void)
 	gint detected;
 
 	radio_vbox = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width(GTK_CONTAINER(radio_vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(radio_vbox), 5);
 
 	frame = gtk_frame_new(_("Options"));
-	gtk_container_border_width(GTK_CONTAINER(frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(radio_vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -125,10 +125,10 @@ GtkWidget *radio_config_init(void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 	gtk_widget_show(label);
 
-	radio_device_entry = gtk_entry_new_with_max_length(255);
+	radio_device_entry = gtk_entry_new();
 	if (radio_device) gtk_entry_set_text(GTK_ENTRY(radio_device_entry), radio_device);
-	gtk_signal_connect(GTK_OBJECT(radio_device_entry), "changed",
-			   GTK_SIGNAL_FUNC(radio_device_changed_cb), NULL);
+	g_signal_connect(G_OBJECT(radio_device_entry), "changed",
+			 G_CALLBACK(radio_device_changed_cb), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox), radio_device_entry, FALSE, FALSE, 5);
 	gtk_widget_show(radio_device_entry);
 
@@ -143,8 +143,8 @@ GtkWidget *radio_config_init(void)
 	gtk_widget_show(radio_detect_button);
 
 	gtk_widget_set_sensitive(radio_detect_button, !detected);
-	gtk_signal_connect(GTK_OBJECT(radio_detect_button), "clicked",
-			   GTK_SIGNAL_FUNC(radio_config_redetect_cb), label);
+	g_signal_connect(G_OBJECT(radio_detect_button), "clicked",
+			 G_CALLBACK(radio_config_redetect_cb), label);
 
 	if (!radio_enabled) gtk_widget_set_sensitive(radio_vbox, FALSE);
 
