@@ -214,7 +214,7 @@ static void xmp_child_shutdown(void)
 			}
 		waitpid (xmp_child_pid, NULL, 0); /* should be WNOHANG */
 		}
-	if (xmp_control_read_id != -1) gdk_input_remove(xmp_control_read_id);
+	if (xmp_control_read_id != -1) g_source_remove(xmp_control_read_id);
 	xmp_control_read_id = -1;
 	close(xmp_pipe_i[0]);
 	close(xmp_pipe_o[1]);
@@ -367,7 +367,7 @@ static char xmp_read_buffer[2048];
 static gint xmp_read_buffer_pos = 0;
 static gint xmp_read_buffer_len = 0;
 
-static void xmp_input_read_cb(gpointer data, int fd, GdkInputCondition condition)
+static gboolean xmp_input_read_cb(GIOChannel *source, GIOCondition condition, gpointer data)
 {
 	gchar buf[2048];
 	gint r;
@@ -375,19 +375,19 @@ static void xmp_input_read_cb(gpointer data, int fd, GdkInputCondition condition
 	gint l;
 	gchar *ptr;
 
-	r = read(fd, buf, sizeof(buf));
+	r = read(xmp_pipe_i[0], buf, sizeof(buf));
 
 	if (r == -1)
 		{
 		xmp_input_error();
-		return;
+		return TRUE;
 		}
 	if (r == 0)
 		{
 		printf(_("xmp disappeared! (unexpected EOF)\n"));
 		xmp_child_gone();
 		xmp_input_error();
-		return;
+		return TRUE;
 		}
 
 	ptr = xmp_read_buffer + xmp_read_buffer_pos;
@@ -409,7 +409,7 @@ static void xmp_input_read_cb(gpointer data, int fd, GdkInputCondition condition
 			}
 		else if (c == '\n')
 			{
-			if (!xmp_input_parse(xmp_read_buffer, xmp_read_buffer_len)) return;
+			if (!xmp_input_parse(xmp_read_buffer, xmp_read_buffer_len)) return TRUE;
 			xmp_read_buffer_len = xmp_read_buffer_pos = 0;
 			}
 		else if (xmp_read_buffer_pos < l)
@@ -421,6 +421,8 @@ static void xmp_input_read_cb(gpointer data, int fd, GdkInputCondition condition
 		}
 
 	xmp_input_parse(xmp_read_buffer, xmp_read_buffer_len);
+
+	return TRUE;
 }
 
 static void xmp_input_read_reset(void)
@@ -444,6 +446,7 @@ static gint xmp_child_run(SongData *sd, gint position)
 	int cmd_cnt = 0;
         gint start_pattern;
 	gchar *exec_bin = XMP_BINARY;
+	GIOChannel *channel;
 
 	cmd_max = sizeof(cmd_arguments) / 16;
 
@@ -588,7 +591,14 @@ static gint xmp_child_run(SongData *sd, gint position)
 	if (debug_mode) printf("xmp pid = %d\n", xmp_child_pid);
 
 	xmp_input_read_reset();
+
+	channel = g_io_channel_unix_new(xmp_pipe_i[0]);
+	xmp_control_read_id = g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, G_IO_IN,
+						  xmp_input_read_cb, NULL, NULL);
+	g_io_channel_unref(channel);
+#if 0
 	xmp_control_read_id = gdk_input_add (xmp_pipe_i[0], GDK_INPUT_READ, xmp_input_read_cb, NULL);
+#endif
 
 	xmp_time_reset(sd, position);
 
