@@ -97,7 +97,8 @@ static GtkWidget *hscale_new(gchar *text, gint n, gint *c_n, gint lower, gint up
 	hscale = gtk_hscale_new (GTK_ADJUSTMENT(adj));
 	gtk_range_set_update_policy (GTK_RANGE (hscale), GTK_UPDATE_DELAYED);
 	gtk_scale_set_digits (GTK_SCALE (hscale), 0);
-	gtk_signal_connect( GTK_OBJECT(adj),"value_changed", GTK_SIGNAL_FUNC(hscale_cb), c_n);
+	g_signal_connect(G_OBJECT(adj), "value_changed",
+			 G_CALLBACK(hscale_cb), c_n);
 
 	if (text)
 		{
@@ -123,7 +124,7 @@ static void checkbox_cb(GtkWidget *w, gpointer data)
 {
 	gint *c_n = data;
 
-	*c_n = GTK_TOGGLE_BUTTON (w)->active;
+	*c_n = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w));
 }
 
 static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
@@ -132,8 +133,9 @@ static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
 
 	*c_n = n;
 	button = gtk_check_button_new_with_label(text);
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), n);
-	gtk_signal_connect (GTK_OBJECT(button), "clicked", (GtkSignalFunc)checkbox_cb, c_n);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), n);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(checkbox_cb), c_n);
 
 	return button;
 }
@@ -179,10 +181,10 @@ GtkWidget *xmp_config_init(void)
 	GtkWidget *hscale;
 
 	xmp_vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (xmp_vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(xmp_vbox), 5);
 
 	frame = gtk_frame_new(_("Sound Options"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(xmp_vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -199,7 +201,7 @@ GtkWidget *xmp_config_init(void)
 	gtk_widget_show(hscale);
 
 	frame = gtk_frame_new(_("Software Mixer"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(xmp_vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
