@@ -161,7 +161,7 @@ void ipc_send(gchar *command)
 	fclose(f);
 }
 
-static gint ipc_read_data(gpointer data)
+static gboolean ipc_read_data(GIOChannel *source, GIOCondition condition, gpointer data)
 {
 	gchar i_buf[1025];
 	i_buf[1024] = '\0'; /* paranoid safety */
@@ -357,6 +357,7 @@ static gint ipc_read_data(gpointer data)
 
 void ipc_on(void)
 {
+	GIOChannel *channel;
 	gchar *pathl;
 
 	if (ipc_file_id || ipc_cb_id > -1) return;
@@ -393,10 +394,17 @@ void ipc_on(void)
 
 	pid_lock_file_create();
 
+	channel = g_io_channel_unix_new(ipc_fd_id);
+	ipc_cb_id = g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, G_IO_IN,
+					ipc_read_data, NULL, NULL);
+	g_io_channel_unref(channel);
+
+#if 0
 	ipc_cb_id = gdk_input_add(ipc_fd_id,
                            GDK_INPUT_READ,
                            (GdkInputFunction) ipc_read_data,
                            NULL);
+#endif
 
 	if (debug_mode) printf("ipc_on\n");
 }
@@ -407,7 +415,10 @@ void ipc_off(void)
 
 	if (ipc_cb_id > -1)
 		{
+		g_source_remove(ipc_cb_id);
+#if 0
 		gdk_input_remove(ipc_cb_id);
+#endif
 		ipc_cb_id = -1;
 		}
 
