@@ -126,6 +126,26 @@ void load_preset(gint n)
 		}
 }
 
+gint preset_is_active(gint n)
+{
+	const gchar *match_path;
+
+	if (n < 0 || n > 9 ||
+	    !preset_name[n] || !preset_file[n]) return FALSE;
+
+	if (current_song_get_number() == -1)
+		{
+		match_path = current_song_get_path();
+		}
+	else
+		{
+		match_path = NULL;
+		}
+
+	return ((!match_path && playlist_pathname && strcmp(playlist_pathname, preset_file[n]) == 0) ||
+		(match_path && strcmp(match_path, preset_file[n]) == 0) );
+}
+
 /*
  *-----------------------------------------------------------------------------
  * current song routines (public)
@@ -186,6 +206,8 @@ void current_song_set(gint n, gchar *path)
 		clear_current_song();
 		current_songdata = playlist_data_new(path, TRUE);
 		current_song_in_playlist = FALSE;
+
+		display_presets_refresh();
 		}
 	else if (n >= 0)
 		{
@@ -1178,8 +1200,6 @@ int main (int argc, char *argv[])
 	 */
 	gtk_init (&argc, &argv);
 
-	gdk_rgb_init();
-
 	buf = g_strconcat(homedir(), "/.gqmpeg/gtkrc", NULL);
 	if (isfile(buf)) gtk_rc_parse(buf);
 	g_free(buf);
