@@ -34,12 +34,12 @@ GtkWidget *mod_create_info_window(const gchar *file)
 	songinfo_add_label(vbox, _("Filename"), filename_from_path(file));
 
 	frame = gtk_frame_new(_("Song info"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox1), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox1), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox1);
         gtk_widget_show(vbox1);
 
