@@ -15,15 +15,23 @@
 
 #include "playlist.h"
 #include "songinfo.h"
-#include "ui_clist_edit.h"
 #include "ui_fileops.h"
+#include "ui_tree_edit.h"
+
+
+enum {
+	COMMENT_COLUMN_LISTP = 0,
+	COMMENT_COLUMN_KEY,
+	COMMENT_COLUMN_VALUE,
+	COLUMNT_COLUMN_COUNT
+};
 
 
 typedef struct _SongInfoDialog SongInfoDialog;
 struct _SongInfoDialog
 {
 	GtkWidget *vbox;
-	GtkWidget *clist;
+	GtkWidget *list;
 	GtkWidget *save_button;
 	GtkWidget *remove_button;
 	gchar *path;
@@ -57,21 +65,29 @@ static void comments_save_cb(GtkWidget *w, gpointer data)
 static void comment_remove_cb(GtkWidget *w, gpointer data)
 {
 	SongInfoDialog *s = data;
+	GtkTreeSelection *selection;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+	GtkTreePath *tpath;
 	gint row;
 	GList *work;
 
-	if (GTK_CLIST(s->clist)->selection == NULL) return;
-	row = GPOINTER_TO_INT(GTK_CLIST(s->clist)->selection->data);
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(s->list));
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	tpath = gtk_tree_model_get_path(store, &iter);
+	row = tree_path_to_row(tpath);
+	gtk_tree_path_free(tpath);
 
 	if (row < comments_reserved_count) return;
 
-	work = gtk_clist_get_row_data(GTK_CLIST(s->clist), row);
+	gtk_tree_model_get(store, &iter, COMMENT_COLUMN_LISTP, &work, -1);
 	if (work && work->next)
 		{
 		s->comments = g_list_remove(s->comments, work->next->data);
 		s->comments = g_list_remove(s->comments, work->data);
 		}
-	gtk_clist_remove(GTK_CLIST(s->clist), row);
+	gtk_list_store_remove(GTK_LIST_STORE(store), &iter);
 
 	gtk_widget_set_sensitive(s->save_button, TRUE);
 }
@@ -79,42 +95,52 @@ static void comment_remove_cb(GtkWidget *w, gpointer data)
 static void comment_add_cb(GtkWidget *w, gpointer data)
 {
 	SongInfoDialog *s = data;
-	gchar *buf[3];
+	GtkListStore *store;
+	GtkTreeIter iter;
 	GList *work;
-	gint row;
 
-	buf[0] = _("Newkey");
-	buf[1] = "";
-	buf[2] = NULL;
-
-	work = g_list_append(NULL, g_strdup(buf[0]));
-	work = g_list_append(work, g_strdup(buf[1]));
+	work = g_list_append(NULL, g_strdup(_("Newkey")));
+	work = g_list_append(work, g_strdup(""));
 	s->comments = g_list_concat(s->comments, work);
 
-	row = gtk_clist_append(GTK_CLIST(s->clist), buf);
-	gtk_clist_set_row_data(GTK_CLIST(s->clist), row, work);
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(s->list)));
+
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   COMMENT_COLUMN_LISTP, work,
+			   COMMENT_COLUMN_KEY, _("Newkey"),
+			   COMMENT_COLUMN_VALUE, NULL, -1);
 
 	gtk_widget_set_sensitive(s->save_button, TRUE);
 }
 
-static gint list_row_rename_cb(ClistEditData *ced, const gchar *oldname, const gchar *newname, gpointer data)
+static gint list_row_rename_cb(TreeEditData *ted, const gchar *oldname, const gchar *newname, gpointer data)
 {
 	SongInfoDialog *s = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 	GList *work;
+	gint iskey;
 
-	work = gtk_clist_get_row_data(GTK_CLIST(ced->clist), ced->row);
+	store = gtk_tree_view_get_model(ted->tree);
+
+	iskey = (ted->column == gtk_tree_view_get_column(ted->tree, COMMENT_COLUMN_KEY - 1));
+
+	gtk_tree_model_get_iter(store, &iter, ted->path);
+	gtk_tree_model_get(store, &iter, COMMENT_COLUMN_LISTP, &work, -1);
 	if (!work)
 		{
-		if (ced->column == 0)
+		if (iskey)
 			{
 			work = g_list_append(work, g_strdup(newname));
 			work = g_list_append(work, g_strdup(""));
 			}
 		else
 			{
-			if (ced->row < comments_reserved_count)
+			gint row = tree_path_to_row(ted->path);
+			if (row < comments_reserved_count)
 				{
-				work = g_list_append(work, g_strdup(comments_reserved[ced->row]));
+				work = g_list_append(work, g_strdup(comments_reserved[row]));
 				}
 			else
 				{
@@ -123,28 +149,86 @@ static gint list_row_rename_cb(ClistEditData *ced, const gchar *oldname, const g
 			work = g_list_append(work, g_strdup(newname));
 			}
 		s->comments = g_list_concat(s->comments, work);
-		gtk_clist_set_row_data(GTK_CLIST(ced->clist), ced->row, work);
+		gtk_list_store_set(GTK_LIST_STORE(store), &iter,
+				   COMMENT_COLUMN_LISTP, work, -1);
 		}
 
-	if (ced->column == 1) work = work->next;
+	if (!iskey) work = work->next;
 	g_free(work->data);
 	work->data = g_strdup(newname);
 
+	gtk_list_store_set(GTK_LIST_STORE(store), &iter,
+			   (iskey) ? COMMENT_COLUMN_KEY : COMMENT_COLUMN_VALUE, newname, -1);
+
 	gtk_widget_set_sensitive(s->save_button, TRUE);
 
 	return TRUE;
 }
 
-static void list_select_cb(GtkWidget *widget, gint row, gint column, GdkEvent *event, gpointer data)
+static gint list_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
 {
 	SongInfoDialog *s = data;
+	GtkTreeModel *store;
+	GtkTreeSelection *selection;
+	GtkTreeViewColumn *tcolumn;
+	GtkTreePath *tpath;
+	GtkTreeIter iter;
+	gint column;
+	gint ret = FALSE;
 
-	if (row == -1 || column == -1) return;
+	if (!gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget), bevent->x, bevent->y,
+					  &tpath, &tcolumn, NULL, NULL))
+		{
+		return FALSE;
+		}
 
-	gtk_widget_set_sensitive(s->remove_button, (row >= comments_reserved_count));
-	if (column == 0 && row < comments_reserved_count) return;
+	if (tcolumn == gtk_tree_view_get_column(GTK_TREE_VIEW(widget), COMMENT_COLUMN_KEY -1))
+		{
+		column = COMMENT_COLUMN_KEY - 1;
+		}
+	else
+		{
+		column = COMMENT_COLUMN_VALUE -1;
+		}
 
-	clist_edit_by_row(GTK_CLIST(s->clist), row, column, list_row_rename_cb, s);
+	store = gtk_tree_view_get_model(GTK_TREE_VIEW(widget));
+	gtk_tree_model_get_iter(store, &iter, tpath);
+
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(widget));
+	if (gtk_tree_selection_iter_is_selected(selection, &iter) &&
+	    !((column == COMMENT_COLUMN_KEY - 1) && tree_path_to_row(tpath) < comments_reserved_count))
+		{
+		const gchar *key;
+		const gchar *value;
+
+		gtk_tree_model_get(store, &iter,
+				   COMMENT_COLUMN_KEY, &key,
+				   COMMENT_COLUMN_VALUE, &value, -1);
+		tree_edit_by_path(GTK_TREE_VIEW(widget), tpath, column,
+				  (column == COMMENT_COLUMN_KEY - 1) ? key : value,
+				  list_row_rename_cb, s);
+		ret = TRUE;
+		}
+
+	gtk_tree_path_free(tpath);
+
+	return ret;
+}
+
+static void list_select_cb(GtkTreeSelection *selection, gpointer data)
+{
+	SongInfoDialog *s = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	if (gtk_tree_selection_get_selected(selection, &store, &iter))
+		{
+		GtkTreePath *tpath;
+
+		tpath = gtk_tree_model_get_path(store, &iter);
+		gtk_widget_set_sensitive(s->remove_button, tree_path_to_row(tpath) >= comments_reserved_count);
+		gtk_tree_path_free(tpath);
+		}
 }
 
 GtkWidget *ogg123_info_window(const gchar *file)
@@ -157,7 +241,10 @@ GtkWidget *ogg123_info_window(const gchar *file)
 	GtkWidget *scrolled;
 	GtkWidget *button;
 	GList *temp, *work;
-	gchar *titles[] = {_("Key"), _("Description"), NULL};
+	GtkListStore *store;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer *renderer;
+	GtkTreeSelection *selection;
 	gint i;
 
 	s = g_new0(SongInfoDialog, 1);
@@ -167,18 +254,19 @@ GtkWidget *ogg123_info_window(const gchar *file)
 	s->path = g_strdup(file);
 
 	s->vbox = gtk_vbox_new(FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(s->vbox), "destroy", (GtkSignalFunc)close_song_info_window, s);
-	gtk_container_border_width(GTK_CONTAINER(s->vbox), 5);
+	g_signal_connect(G_OBJECT(s->vbox), "destroy",
+			 G_CALLBACK(close_song_info_window), s);
+	gtk_container_set_border_width(GTK_CONTAINER(s->vbox), 5);
 
 	songinfo_add_label(s->vbox, _("Filename"), filename_from_path(file));
 
 	frame = gtk_frame_new(_("Song info"));
-	gtk_container_border_width(GTK_CONTAINER(frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(s->vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox1), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 5);
         gtk_container_add(GTK_CONTAINER(frame),vbox1);
         gtk_widget_show(vbox1);
 
@@ -222,12 +310,12 @@ GtkWidget *ogg123_info_window(const gchar *file)
 		}
 
 	frame = gtk_frame_new(_("Comments"));
-	gtk_container_border_width(GTK_CONTAINER(frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(s->vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width(GTK_CONTAINER (vbox1), 5);
+	gtk_container_set_border_width(GTK_CONTAINER (vbox1), 5);
         gtk_container_add(GTK_CONTAINER(frame), vbox1);
         gtk_widget_show(vbox1);
 
@@ -237,39 +325,59 @@ GtkWidget *ogg123_info_window(const gchar *file)
 	gtk_box_pack_start(GTK_BOX(vbox1), scrolled, TRUE, TRUE, 5);
 	gtk_widget_show(scrolled);
 
-	s->clist = gtk_clist_new_with_titles(2, titles);
-	gtk_widget_set_usize(s->clist, 300, 150);
-	gtk_clist_set_column_auto_resize(GTK_CLIST(s->clist), 0, TRUE);
-	gtk_clist_set_column_auto_resize(GTK_CLIST(s->clist), 1, TRUE);
-	gtk_clist_column_titles_passive(GTK_CLIST(s->clist));
-	gtk_signal_connect(GTK_OBJECT(s->clist), "select_row",
-			   GTK_SIGNAL_FUNC(list_select_cb), s);
-	gtk_container_add(GTK_CONTAINER(scrolled), s->clist);
-	gtk_widget_show(s->clist);
+	store = gtk_list_store_new(3, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING);
+	s->list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	g_object_unref(store);
+
+	gtk_widget_set_size_request(s->list, 300, 150);
+	g_signal_connect(G_OBJECT(s->list), "button_press_event",
+			 G_CALLBACK(list_press_cb), s);
+	gtk_container_add(GTK_CONTAINER(scrolled), s->list);
+	gtk_widget_show(s->list);
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Key"));
+	gtk_tree_view_column_set_resizable(column, TRUE);
+	renderer = gtk_cell_renderer_text_new();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_add_attribute(column, renderer, "text", COMMENT_COLUMN_KEY);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(s->list), column);
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Description"));
+	gtk_tree_view_column_set_resizable(column, TRUE);
+	renderer = gtk_cell_renderer_text_new();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_add_attribute(column, renderer, "text", COMMENT_COLUMN_VALUE);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(s->list), column);
+
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(s->list));
+	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
+	g_signal_connect(G_OBJECT(selection), "changed",
+			 G_CALLBACK(list_select_cb), s);
 
 	hbox = gtk_hbutton_box_new();
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 0);
-	gtk_button_box_set_child_size(GTK_BUTTON_BOX(hbox), 95, 30);
+	gtk_box_set_spacing(GTK_BOX(hbox), 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	button = gtk_button_new_with_label(_("Add"));
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(comment_add_cb), s);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(comment_add_cb), s);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
 	gtk_widget_show(button);
 
 	s->remove_button = gtk_button_new_with_label(_("Remove"));
-	gtk_signal_connect(GTK_OBJECT(s->remove_button), "clicked",
-			   GTK_SIGNAL_FUNC(comment_remove_cb), s);
+	g_signal_connect(G_OBJECT(s->remove_button), "clicked",
+			 G_CALLBACK(comment_remove_cb), s);
 	gtk_container_add(GTK_CONTAINER(hbox), s->remove_button);
 	gtk_widget_set_sensitive(s->remove_button, FALSE);
 	gtk_widget_show(s->remove_button);
 
 	s->save_button = gtk_button_new_with_label(_("Save Comments"));
-	gtk_signal_connect(GTK_OBJECT(s->save_button), "clicked",
-			   GTK_SIGNAL_FUNC(comments_save_cb), s);
+	g_signal_connect(G_OBJECT(s->save_button), "clicked",
+			 G_CALLBACK(comments_save_cb), s);
 	gtk_container_add(GTK_CONTAINER(hbox), s->save_button);
 	gtk_widget_set_sensitive(s->save_button, FALSE);
 	gtk_widget_show(s->save_button);
@@ -278,9 +386,8 @@ GtkWidget *ogg123_info_window(const gchar *file)
 	i = 0;
 	while (comments_reserved[i] != NULL)
 		{
-		gchar *buf[3];
-		gint row;
 		GList *found = NULL;
+		GtkTreeIter iter;
 
 		work = s->comments;
 		while (work && work->next && !found)
@@ -291,12 +398,11 @@ GtkWidget *ogg123_info_window(const gchar *file)
 			work = work->next;
 			}
 
-		buf[0] = comments_reserved[i];
-		buf[1] = found ? found->next->data : "";
-		buf[2] = NULL;
-
-		row = gtk_clist_append(GTK_CLIST(s->clist), buf);
-		gtk_clist_set_row_data(GTK_CLIST(s->clist), row, found);
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter,
+				   COMMENT_COLUMN_LISTP, found,
+				   COMMENT_COLUMN_KEY, comments_reserved[i],
+				   COMMENT_COLUMN_VALUE, (found) ? found->next->data : NULL, -1);
 
 		if (found)
 			{
@@ -309,15 +415,13 @@ GtkWidget *ogg123_info_window(const gchar *file)
 	work = temp;
 	while (work && work->next)
 		{
-		gchar *buf[3];
-		gint row;
+		GtkTreeIter iter;
 
-		buf[0] = work->data;
-		buf[1] = work->next->data;
-		buf[2] = NULL;
-
-		row = gtk_clist_append(GTK_CLIST(s->clist), buf);
-		gtk_clist_set_row_data(GTK_CLIST(s->clist), row, g_list_find(s->comments, work->data));
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter,
+				   COMMENT_COLUMN_LISTP, g_list_find(s->comments, work->data),
+				   COMMENT_COLUMN_KEY, work->data,
+				   COMMENT_COLUMN_VALUE, work->next->data, -1);
 
 		work = work->next;
 		work = work->next;
