@@ -71,7 +71,7 @@ static GenericDialog *playlist_save_confirmed(FileDialog *fd, gint overwrite)
 		gd = generic_dialog_new(_("Overwrite File"), buf, "GQmpeg", "confirm", TRUE,
 					playlist_confirm_cancel, fd);
 		g_free(buf);
-		generic_dialog_add(gd, _("Overwrite"), playlist_confirm_ok, TRUE);
+		generic_dialog_add_stock(gd, _("Overwrite"), GTK_STOCK_OK, playlist_confirm_ok, TRUE);
 
 		gtk_widget_show(gd->dialog);
 
@@ -348,7 +348,7 @@ void playlist_dialog_add_custom_type(gint to_playlist)
 	dcd->gd = generic_dialog_new(title, NULL,
 				     "GQmpeg", "custom_add", FALSE,
 				     playlist_dialog_custom_close_cb, dcd);
-	generic_dialog_add(dcd->gd, _("Ok"), playlist_dialog_custom_add_cb, TRUE);
+	generic_dialog_add_stock(dcd->gd, NULL, GTK_STOCK_OK, playlist_dialog_custom_add_cb, TRUE);
 
 	optionmenu = gtk_option_menu_new();
 	gtk_box_pack_start(GTK_BOX(dcd->gd->vbox), optionmenu, FALSE, FALSE,0);
@@ -447,7 +447,7 @@ void playlist_dialog_edit_custom_type(SongData *sd)
 	gd = generic_dialog_new(_("GQmpeg - edit custom song type"), NULL,
 				"GQmpeg", "custom_edit", FALSE,
 				playlist_dialog_custom_edit_close_cb, dcd);
-	generic_dialog_add(gd, _("Change"), playlist_dialog_custom_edit_change_cb, TRUE);
+	generic_dialog_add_stock(gd, NULL, GTK_STOCK_OK, playlist_dialog_custom_edit_change_cb, TRUE);
 
 	dcd->entry = typelist_get_edit_widget_by_id(sd->custom_type, sd);
 	if (!dcd->entry)
