@@ -398,7 +398,7 @@ static void list_add_column(GtkWidget *tree, const gchar *title, gint column_id,
 		gtk_tree_view_column_set_min_width(column, 4);
 		if (size > 0) gtk_tree_view_column_set_fixed_width(column, size);
 		gtk_tree_view_column_set_sizing(column,
-			(image || size == 0) ? GTK_TREE_VIEW_COLUMN_AUTOSIZE : GTK_TREE_VIEW_COLUMN_FIXED);
+			(image || size == 0) ? GTK_TREE_VIEW_COLUMN_GROW_ONLY : GTK_TREE_VIEW_COLUMN_FIXED);
 		gtk_tree_view_column_set_resizable(column, (!image));
 		}
 	else
@@ -1800,7 +1800,7 @@ static gint playlist_window_drag_scroll_cb(gpointer data)
 
 	window = GTK_CLIST(playlist_clist)->clist_window;
 	gdk_window_get_pointer(window, &x, &y, NULL);
-	gdk_window_get_size(window, &w, &h);
+	gdk_drawable_get_size(window, &w, &h);
 
 	/* check bounds, remove if out */
 	if (x < 0 || x >= w || y < 0 || y >= h)
@@ -2161,6 +2161,19 @@ static void playlist_window_dnd_init(void)
  *-----------------------------------------------------------------------------
  */
 
+static GtkWidget *button_new(GtkWidget *box, const gchar *text,
+			     GCallback func, gpointer data)
+{
+	GtkWidget *button;
+
+	button = gtk_button_new_with_mnemonic(text);
+	if (func) g_signal_connect(G_OBJECT(button), "clicked", func, data);
+	gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
+	gtk_widget_show(button);
+
+	return button;
+}
+
 void playlist_window_toggle(void)
 {
 	if (playlist_window) 
@@ -2198,7 +2211,7 @@ void playlist_window_hide(void)
 	widget_auto_scroll_stop(playlist_view);
 
 	gdk_window_get_root_origin(playlist_window->window, &window_list_x, &window_list_y);
-	gdk_window_get_size(playlist_window->window, &window_list_w, &window_list_h);
+	gdk_drawable_get_size(playlist_window->window, &window_list_w, &window_list_h);
 	window_list_div_dir = s_scrolled->allocation.height;
 	window_list_div_mid = s_hbox->allocation.width;
 
@@ -2355,17 +2368,8 @@ static void playlist_window_build(void)
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 5);
 	gtk_widget_show(hbox1);
 
-	button = gtk_button_new_with_label(_("Home"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(change_dir_to_home), NULL);
-	gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Close"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(playlist_window_hide), NULL);
-	gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(hbox1, _("_Home"), G_CALLBACK(change_dir_to_home), NULL);
+	button_new(hbox1, _("Close"), G_CALLBACK(playlist_window_hide), NULL);
 
 	frame = gtk_frame_new(_("Playlist"));
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
@@ -2376,17 +2380,8 @@ static void playlist_window_build(void)
 	gtk_container_add(GTK_CONTAINER(frame),vbox2);
 	gtk_widget_show(vbox2);
 
-	button = gtk_button_new_with_label(_("Save"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(save_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Save as..."));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(save_as_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(vbox2, _("_Save"), G_CALLBACK(save_pressed), NULL);
+	button_new(vbox2, _("Sa_ve as..."), G_CALLBACK(save_as_pressed), NULL);
 
 	button = gtk_check_button_new_with_label(_("save mode"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), save_mode_in_playlist);
@@ -2395,17 +2390,8 @@ static void playlist_window_build(void)
 	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
 	gtk_widget_show(button);
 
-	button = gtk_button_new_with_label(_("Open"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(btn_load_playlist_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Append"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(append_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(vbox2, _("_Open"), G_CALLBACK(btn_load_playlist_pressed), NULL);
+	button_new(vbox2, _("A_ppend"), G_CALLBACK(append_pressed), NULL);
 
 	frame = gtk_frame_new(_("Move Song"));
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
@@ -2420,33 +2406,15 @@ static void playlist_window_build(void)
 	gtk_box_pack_start(GTK_BOX(hbox1), vbox2, TRUE, TRUE, 0);
 	gtk_widget_show(vbox2);
 
-	button = gtk_button_new_with_label(_("Top"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(top_button_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("End"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(end_button_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(vbox2, _("_Top"), G_CALLBACK(top_button_pressed), NULL);
+	button_new(vbox2, _("_End"), G_CALLBACK(end_button_pressed), NULL);
 
 	vbox2 = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox1), vbox2, TRUE, TRUE, 0);
 	gtk_widget_show(vbox2);
 
-	button = gtk_button_new_with_label(_("Up"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(up_button_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Down"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(down_button_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(vbox2, _("_Up"), G_CALLBACK(up_button_pressed), NULL);
+	button_new(vbox2, _("_Down"), G_CALLBACK(down_button_pressed), NULL);
 
 	frame = gtk_frame_new(_("Songs"));
 	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
@@ -2457,45 +2425,17 @@ static void playlist_window_build(void)
 	gtk_container_add(GTK_CONTAINER(frame),vbox2);
 	gtk_widget_show(vbox2);
 
-	button = gtk_button_new_with_label(_("Add All"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(add_all_button_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Add"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(plw_filelist_add_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Insert"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(plw_filelist_insert_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Remove"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(plw_playlist_remove_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("Remove All"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(remove_all_button_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(vbox2, _("Add A_ll"), G_CALLBACK(add_all_button_pressed), NULL);
+	button_new(vbox2, _("_Add"), G_CALLBACK(plw_filelist_add_pressed), NULL);
+	button_new(vbox2, _("_Insert"), G_CALLBACK(plw_filelist_insert_pressed), NULL);
+	button_new(vbox2, _("_Remove"), G_CALLBACK(plw_playlist_remove_pressed), NULL);
+	button_new(vbox2, _("Re_move All"), G_CALLBACK(remove_all_button_pressed), NULL);
 
 	button = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 5);
 	gtk_widget_show(button);
 
-	button = gtk_button_new_with_label(_("Add Custom"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(add_custom_pressed), NULL);
-	gtk_box_pack_start(GTK_BOX(vbox2), button, TRUE, TRUE, 0);
-	gtk_widget_show(button);
+	button_new(vbox2, _("Add _Custom"), G_CALLBACK(add_custom_pressed), NULL);
 
 	/* play list */
 	store = gtk_list_store_new(10, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,
