@@ -96,6 +96,12 @@ static void spin_cb(GtkObject *adj, gpointer data)
 	*c_n = (gint)(GTK_ADJUSTMENT(adj)->value);
 }
 
+static void hscale_centered_cb(GtkObject *adj, gpointer data)
+{
+	gint *c_n = data;
+
+	*c_n = (gint)(GTK_ADJUSTMENT(adj)->value / 200.0 * 255.0 + 128.0);
+}
 
 static void hscale_cb(GtkObject *adj, gpointer data)
 {
@@ -104,18 +110,34 @@ static void hscale_cb(GtkObject *adj, gpointer data)
 	*c_n = (gint)(GTK_ADJUSTMENT(adj)->value / 100.0 * 255.0);
 }
 
-static GtkWidget *hscale_new(gint n, gint *c_n)
+static GtkWidget *hscale_new(GtkWidget *box, const gchar *text, gint n, gint *c_n, gint centered)
 {
 	GtkObject *adj;
         GtkWidget *hscale;
 
 	*c_n = n;
-	adj = gtk_adjustment_new((float)n / 255.0 * 100.0, 0.0, 100.0, 1.0, 1.0, 0.0);
-        hscale = gtk_hscale_new (GTK_ADJUSTMENT(adj));
-        gtk_range_set_update_policy (GTK_RANGE (hscale), GTK_UPDATE_DELAYED);
-        gtk_scale_set_digits (GTK_SCALE (hscale), 0);
-        g_signal_connect(G_OBJECT(adj), "value_changed",
-			 G_CALLBACK(hscale_cb), c_n);
+
+	if (centered)
+		{
+		hscale = ui_edit_spin_new_with_scale(box, text, -100, 100, &adj);
+		gtk_adjustment_set_value(GTK_ADJUSTMENT(adj), ((float)n - 128.0) / 255.0 * 200.0);
+		}
+	else
+		{
+		hscale = ui_edit_spin_new_with_scale(box, text, 0, 100, &adj);
+		gtk_adjustment_set_value(GTK_ADJUSTMENT(adj), (float)n / 255.0 * 100.0);
+		}
+
+	if (centered)
+		{
+		g_signal_connect(G_OBJECT(adj), "value_changed",
+				 G_CALLBACK(hscale_centered_cb), c_n);
+		}
+	else
+		{
+		g_signal_connect(G_OBJECT(adj), "value_changed",
+				 G_CALLBACK(hscale_cb), c_n);
+		}
 
 	return hscale;
 }
@@ -127,7 +149,7 @@ static void checkbox_cb(GtkWidget *w, gpointer data)
 	*c_n = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w));
 }
 
-static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
+static GtkWidget *checkbox_new(GtkWidget *box, gchar *text, gint n, gint *c_n)
 {
         GtkWidget *button;
 
@@ -137,9 +159,32 @@ static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(checkbox_cb), c_n);
 
+	if (box)
+		{
+		gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
+		gtk_widget_show(button);
+		}
+
 	return button;
 }
 
+static GtkWidget *vframe_new(GtkWidget *box, gint has_frame, const gchar *text)
+{
+	GtkWidget *vbox;
+
+	vbox = ui_edit_vframe_new(box, has_frame, text);
+
+	if (has_frame)
+		{
+		GtkWidget *frame;
+
+		frame = gtk_widget_get_parent(vbox);
+		gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
+		}
+
+	return vbox;
+}
+
 static void mixer_device_id_cb(GtkWidget *w, gpointer data)
 {
 	gchar *dev_text = data;
@@ -192,6 +237,7 @@ static void skin_item_selected(GtkTreeSelection *selection, gpointer data)
 
 	gtk_tree_model_get(store, &iter, SKIN_COLUMN_PATH, &path, -1);
 	gtk_entry_set_text(GTK_ENTRY(default_skin_entry), (path) ? path : "");
+	g_free(path);
 }
 
 static gint sort_skin_list_cb(void *a, void *b)
@@ -230,9 +276,7 @@ static void populate_skin_list(GtkListStore *store)
 	g_free(skinpath);
 
 	/* add system dir skins */
-	skinpath = g_strconcat(GQMPEG_SKINDIR, NULL);
-	skin_list = skin_list_add_dir(skin_list, skinpath);
-	g_free(skinpath);
+	skin_list = skin_list_add_dir(skin_list, GQMPEG_SKINDIR);
 
 	skin_list = g_list_sort(skin_list, (GCompareFunc) sort_skin_list_cb);
 
@@ -496,7 +540,6 @@ static void create_config_window(gint start_tab)
 	GList *devices;
 	GList *list;
 	gint lh, cnt, i;
-        GtkWidget *hscale;
 
 	GtkObject *adj;
 	GtkWidget *spin;
@@ -527,7 +570,7 @@ static void create_config_window(gint start_tab)
 	gtk_box_pack_end(GTK_BOX(configvbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	button = gtk_button_new_with_label(_("Ok"));
+	button = gtk_button_new_from_stock(GTK_STOCK_OK);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(ok_configuration_window), NULL);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
@@ -536,14 +579,14 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(button);
 
 
-	button = gtk_button_new_with_label(_("Apply"));
+	button = gtk_button_new_from_stock(GTK_STOCK_APPLY);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(apply_configuration_window), NULL);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_widget_show(button);
 
-	button = gtk_button_new_with_label(_("Cancel"));
+	button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(hide_configuration_window), NULL);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
@@ -566,74 +609,25 @@ static void create_config_window(gint start_tab)
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
-	
-	frame = gtk_frame_new(_("Song Information"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame),vbox1);
-	gtk_widget_show(vbox1);
+	vbox1 = vframe_new(vbox, TRUE, _("Song Information"));
 
-	button = checkbox_new(_("Read file headers (enables playlist length calculation)"), read_file_information, &c_read_file_information);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox1, _("Read file headers (enables playlist length calculation)"), read_file_information, &c_read_file_information);
 
-	frame = gtk_frame_new(_("Window"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
+	vbox1 = vframe_new(vbox, TRUE, _("Window"));
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame),vbox1);
-	gtk_widget_show(vbox1);
+	checkbox_new(vbox1, _("Smart window placement"), slik_smart_placement, &c_slik_smart_placement);
+	checkbox_new(vbox1, _("Remember window position"), slik_remember_position, &c_slik_remember_position);
+	checkbox_new(vbox1, _("Enable window manager decorations"), wm_decorations, &c_wm_decorations);
+	checkbox_new(vbox1, _("Double sized window"), slik_double_size, &c_slik_double_size);
 
-	button = checkbox_new(_("Smart window placement"), slik_smart_placement, &c_slik_smart_placement);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	vbox1 = vframe_new(vbox, TRUE, _("Title Display"));
 
-	button = checkbox_new(_("Remember window position"), slik_remember_position, &c_slik_remember_position);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox1, _("Always scroll title"), title_scrolls_always, &c_title_scrolls_always);
+	checkbox_new(vbox1, _("Show filename extension"), title_show_extension, &c_title_show_extension);
+	checkbox_new(vbox1, _("Convert underscores to spaces"), title_convert_underscores, &c_title_convert_underscores);
 
-	button = checkbox_new(_("Enable window manager decorations"), wm_decorations, &c_wm_decorations);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Double sized window"), slik_double_size, &c_slik_double_size);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	frame = gtk_frame_new(_("Title Display"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
-
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame),vbox1);
-	gtk_widget_show(vbox1);
-
-	button = checkbox_new(_("Always scroll title"), title_scrolls_always, &c_title_scrolls_always);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Show filename extension"), title_show_extension, &c_title_show_extension);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Convert underscores to spaces"), title_convert_underscores, &c_title_convert_underscores);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	frame = gtk_frame_new(_("Mixer"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
-
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame),vbox1);
-	gtk_widget_show(vbox1);
+	vbox1 = vframe_new(vbox, TRUE, _("Mixer"));
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
@@ -685,13 +679,8 @@ static void create_config_window(gint start_tab)
 	gtk_box_pack_start(GTK_BOX(hbox), omenu, TRUE, TRUE, 5);
 	gtk_widget_show(omenu);
 
-	button = checkbox_new(_("First press of prev restarts song when playing"), prev_includes_current, &c_prev_includes_current);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Allow command parsing through ~/.gqmpeg/command"), allow_ipc, &c_allow_ipc);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox, _("First press of prev restarts song when playing"), prev_includes_current, &c_prev_includes_current);
+	checkbox_new(vbox, _("Allow command parsing through ~/.gqmpeg/command"), allow_ipc, &c_allow_ipc);
 
 	hbox = gtk_hbox_new (FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
@@ -721,15 +710,8 @@ static void create_config_window(gint start_tab)
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
-	
-	frame = gtk_frame_new(_("Initial playlist"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame),vbox1);
-	gtk_widget_show(vbox1);
+	vbox1 = vframe_new(vbox, TRUE, _("Initial playlist"));
 
 	c_initial_playlist_mode = initial_playlist_mode;
 	radiobutton = gtk_radio_button_new_with_label (NULL, _("Empty"));
@@ -778,26 +760,11 @@ static void create_config_window(gint start_tab)
 	gtk_box_pack_end(GTK_BOX(hbox),button,FALSE,FALSE,0);
 	gtk_widget_show(button);
 
-	frame = gtk_frame_new(_("When program starts:"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
+	vbox1 = vframe_new(vbox, TRUE, _("When program starts:"));
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame),vbox1);
-	gtk_widget_show(vbox1);
-
-	button = checkbox_new(_("Start playing"), start_playing_on_startup, &c_start_playing_on_startup);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Show playlist window"), show_playlist_on_startup, &c_show_playlist_on_startup);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Change to this directory:"), initial_directory_enable, &c_initial_directory_enable);
-	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox1, _("Start playing"), start_playing_on_startup, &c_start_playing_on_startup);
+	checkbox_new(vbox1, _("Show playlist window"), show_playlist_on_startup, &c_show_playlist_on_startup);
+	checkbox_new(vbox1, _("Change to this directory:"), initial_directory_enable, &c_initial_directory_enable);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
@@ -855,42 +822,19 @@ static void create_config_window(gint start_tab)
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
 
-	button = checkbox_new(_("Obey shuffle / repeat if saved in playlist"), obey_mode_in_playlist, &c_obey_mode_in_playlist);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox, _("Obey shuffle / repeat if saved in playlist"), obey_mode_in_playlist, &c_obey_mode_in_playlist);
+	checkbox_new(vbox, _("Show hidden files and directories in playlist window"), show_dot_files, &c_show_dot_files);
+	checkbox_new(vbox, _("Show all files in the playlist window"), disable_filtering, &c_disable_filtering);
+	checkbox_new(vbox, _("Add single item drops on main window to playlist"), drop_single_to_playlist, &c_drop_single_to_playlist);
+	checkbox_new(vbox, _("Play next song on error"), play_next_on_error, &c_play_next_on_error);
 
-	button = checkbox_new(_("Show hidden files and directories in playlist window"), show_dot_files, &c_show_dot_files);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Show all files in the playlist window"), disable_filtering, &c_disable_filtering);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Add single item drops on main window to playlist"), drop_single_to_playlist, &c_drop_single_to_playlist);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Play next song on error"), play_next_on_error, &c_play_next_on_error);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	frame = gtk_frame_new(_("Flybys"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
-
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame), vbox1);
-	gtk_widget_show(vbox1);
+	vbox1 = vframe_new(vbox, TRUE, _("Flybys"));
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	button = checkbox_new(_("Enable flybys"), flyby_enabled, &c_flyby_enabled);
-	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(hbox, _("Enable flybys"), flyby_enabled, &c_flyby_enabled);
 
 	c_flyby_location = flyby_location;
 
@@ -962,9 +906,7 @@ static void create_config_window(gint start_tab)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	button = checkbox_new(_("Play presets immediately"), play_presets, &c_play_presets);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox, _("Play presets immediately"), play_presets, &c_play_presets);
 
 	/* skin tab */
 
@@ -1011,72 +953,28 @@ static void create_config_window(gint start_tab)
 
 	g_free(skin_label_text);
 
-	button = checkbox_new(_("Display cpu and frame information in amp skins"), show_extra_winamp_info, &c_show_extra_winamp_info);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox, _("Display cpu and frame information in amp skins"), show_extra_winamp_info, &c_show_extra_winamp_info);
 
 /*---*/
 
-	frame = gtk_frame_new(_("Skin Adjustment"));
-	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
-	gtk_widget_show(frame);
+	vbox1 = vframe_new(vbox, TRUE, _("Skin Adjustment"));
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER(frame), vbox1);
-	gtk_widget_show(vbox1);
+	hbox = ui_edit_frame_new(vbox1, FALSE, NULL);
 
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	checkbox_new(hbox, _("Color tint:"), slik_colorshift_on, &c_slik_colorshift_on);
+	hscale_new(hbox, NULL, slik_colorshift_a, &c_slik_colorshift_a, FALSE);
 
-	button = checkbox_new(_("Color shift (RGB)"), slik_colorshift_on, &c_slik_colorshift_on);
-	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	hscale_new(vbox1, "R", slik_colorshift_r, &c_slik_colorshift_r, TRUE);
+	hscale_new(vbox1, "G", slik_colorshift_g, &c_slik_colorshift_g, TRUE);
+	hscale_new(vbox1, "B", slik_colorshift_b, &c_slik_colorshift_b, TRUE);
 
-	hscale = hscale_new(slik_colorshift_r, &c_slik_colorshift_r);
-        gtk_box_pack_start(GTK_BOX(hbox), hscale, TRUE, TRUE, 0);
-        gtk_widget_show(hscale);
+	hbox = ui_edit_frame_new(vbox1, FALSE, NULL);
 
-	hscale = hscale_new(slik_colorshift_g, &c_slik_colorshift_g);
-        gtk_box_pack_start(GTK_BOX(hbox), hscale, TRUE, TRUE, 0);
-        gtk_widget_show(hscale);
+	checkbox_new(hbox, _("Force transparency"), slik_transparency_force, &c_slik_transparency_force);
+	hscale_new(hbox, NULL, slik_transparency_force_a, &c_slik_transparency_force_a, FALSE);
 
-	hscale = hscale_new(slik_colorshift_b, &c_slik_colorshift_b);
-        gtk_box_pack_start(GTK_BOX(hbox), hscale, TRUE, TRUE, 0);
-        gtk_widget_show(hscale);
-	
-	label = gtk_label_new(_("Percent:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-
-	hscale = hscale_new(slik_colorshift_a, &c_slik_colorshift_a);
-        gtk_box_pack_start(GTK_BOX(hbox), hscale, TRUE, TRUE, 0);
-        gtk_widget_show(hscale);
-
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
-	button = checkbox_new(_("Force transparency"), slik_transparency_force, &c_slik_transparency_force);
-	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	label = gtk_label_new(_("Percent:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-
-	hscale = hscale_new(slik_transparency_force_a, &c_slik_transparency_force_a);
-        gtk_box_pack_start(GTK_BOX(hbox), hscale, TRUE, TRUE, 0);
-        gtk_widget_show(hscale);
-
-	button = checkbox_new(_("Enable menu skins"), skinned_menus_enable, &c_skinned_menus_enable);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = checkbox_new(_("Enable keyboard focus"), slik_focus_enable, &c_slik_focus_enable);
-	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	checkbox_new(vbox, _("Enable menu skins"), skinned_menus_enable, &c_skinned_menus_enable);
+	checkbox_new(vbox, _("Enable keyboard focus"), slik_focus_enable, &c_slik_focus_enable);
 
 	sep = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(vbox), sep, FALSE, FALSE, 0);
