@@ -23,7 +23,7 @@
 #include "ui2_widget.h"
 
 
-#define GQMPEG_SKIN_FONT "-*-helvetica-bold-r-*-*-14-*-*-*-*-*-*-*"
+#define GQMPEG_SKIN_FONT "Sans Bold 10"
 
 
 #include "default_skin/back.xpm"
@@ -229,7 +229,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		skin->border_top = 60;
 		skin->border_bottom = 66;
 
-		add_text("playlist", GQMPEG_SKIN_FONT, 205, FALSE, 0, 255, 255, 255, 150, 91, 6, skin, NULL);
+		add_text("playlist", GQMPEG_SKIN_FONT, 205, FALSE, 0, 255, 255, 255, 150, 91, 4, skin, NULL);
 
 		wd = add_button("playlist", (gchar **)btn_playlist_xpm, TRUE, FALSE, 10, 202, NULL, skin, NULL);
 		ui_widget_set_anchor(wd, FALSE, TRUE);
@@ -248,7 +248,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		list_image_row(ld, gdk_pixbuf_new_from_xpm_data((const char **)list_row_xpm),
 			       TRUE, TRUE, 1, 1, FALSE, NULL);
 		list_image_row_flag(ld, gdk_pixbuf_new_from_xpm_data((const char **)list_flags_xpm), 4, 0);
-		list_set_font(ld, "-*-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*", NULL, FALSE, 0, 0, 0, 200);
+		list_set_font(ld, "Sans Bold 9", NULL, FALSE, 0, 0, 0, 200);
 
 		list_set_column_attributes(ld, 0, 30, UI_LIST_COLUMN_SIZE_FIXED | UI_LIST_COLUMN_JUSTIFY_RIGHT, "number");
 		list_set_column_attributes(ld, 1, 78, UI_LIST_COLUMN_SIZE_PROPORTIONAL, "title");
@@ -304,7 +304,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 
 		if (strcmp(key, "skindata_vert_l") == 0)
 			{
-			add_text("title", GQMPEG_SKIN_FONT, 127, FALSE, 270, 0, 0, 0, 179, 4, 110, skin, NULL);
+			add_text("title", GQMPEG_SKIN_FONT, 127, FALSE, 270, 0, 0, 0, 179, 2, 110, skin, NULL);
 			add_number("second", 2, 270, TRUE, FALSE, 4, 57, ds, skin, NULL);
 			add_number("minute", 2, 270, FALSE, FALSE, 4, 85, ds, skin, NULL);
 			add_item("dummycolon", (gchar **)itm_vcolon_xpm, 1, 8, 82, skin, NULL);
@@ -345,7 +345,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		/* small mode */
 		skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)back_mini_xpm), TRUE);
 
-		add_text("title", GQMPEG_SKIN_FONT, 90, FALSE, 0, 0, 0, 0, 179, 6, 4, skin, NULL);
+		add_text("title", GQMPEG_SKIN_FONT, 90, FALSE, 0, 0, 0, 0, 179, 6, 2, skin, NULL);
 
 		add_button("playlist", (gchar **)btn_mlist_xpm, TRUE, FALSE, 174, 4, NULL, skin, NULL);
 
@@ -377,7 +377,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		/* main mode */
 		skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)back_xpm), TRUE);
 
-		add_text("title", GQMPEG_SKIN_FONT, 192, FALSE, 0, 0, 0, 0, 179, 104, 32, skin, NULL);
+		add_text("title", GQMPEG_SKIN_FONT, 192, FALSE, 0, 0, 0, 0, 179, 104, 30, skin, NULL);
 
 		add_button("playlist", (gchar **)btn_playlist_xpm, TRUE, FALSE, 10, 47, NULL, skin, NULL);
 
@@ -463,8 +463,8 @@ SkinData *skin_load_default_flyby_cb(UIData *ui, const gchar *key, gpointer data
 
 	skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)flyby_back_xpm), TRUE);
 
-	add_text("title", GQMPEG_SKIN_FONT, 236, FALSE, 0, 0, 0, 0, 179, 7, 7, skin, NULL);
-	add_text("artist", GQMPEG_SKIN_FONT, 206, FALSE, 0, 0, 0, 0, 179, 7, 25, skin, NULL);
+	add_text("title", GQMPEG_SKIN_FONT, 236, FALSE, 0, 0, 0, 0, 179, 7, 5, skin, NULL);
+	add_text("artist", GQMPEG_SKIN_FONT, 206, FALSE, 0, 0, 0, 0, 179, 7, 23, skin, NULL);
 
 	add_button("next", (gchar **)btn_snext_xpm, TRUE, FALSE, 231, 30, NULL, skin, NULL);
 	add_button("prev", (gchar **)btn_sprev_xpm, TRUE, FALSE, 218, 30, NULL, skin, NULL);
