@@ -72,8 +72,8 @@ void ui_display_render_area(UIData *ui, gint x, gint y, gint w, gint h, WidgetDa
 				      x, y, x, y, w, h,
 				      GDK_RGB_DITHER_NONE, 1, 1); /* FIXME: no dithering */
 
-	gdk_draw_pixmap(ui->display->window, ui->display->style->fg_gc[GTK_WIDGET_STATE(ui->display)],
-			pixmap, x, y, x, y, w, h);
+	gdk_draw_drawable(ui->display->window, ui->display->style->fg_gc[GTK_WIDGET_STATE(ui->display)],
+			  pixmap, x, y, x, y, w, h);
 }
 
 void ui_display_redraw_area(UIData *ui, gint x, gint y, gint w, gint h, gint update)
@@ -259,11 +259,11 @@ static void ui_display_expose(GtkWidget *widget, GdkEventExpose *event, gpointer
 	pixmap = skin_get_buffer(ui->skin);
 	if (!pixmap) return;
 
-	gdk_draw_pixmap(ui->display->window, ui->display->style->fg_gc[GTK_WIDGET_STATE(ui->display)],
-			pixmap,
-			(gint)event->area.x, (gint)event->area.y,
-			(gint)event->area.x, (gint)event->area.y,
-			(gint)event->area.width, (gint)event->area.height);
+	gdk_draw_drawable(ui->display->window, ui->display->style->fg_gc[GTK_WIDGET_STATE(ui->display)],
+			  pixmap,
+			  (gint)event->area.x, (gint)event->area.y,
+			  (gint)event->area.x, (gint)event->area.y,
+			  (gint)event->area.width, (gint)event->area.height);
 }
 
 static gint ui_display_move_idle_cb(gpointer data)
@@ -743,7 +743,8 @@ static gint ui_display_motion(GtkWidget *w, GdkEventMotion *event, gpointer data
 		gdk_window_get_pointer (NULL, &px, &py, &modmask);
 		px -= ui->press_x;
 		py -= ui->press_y;
-		if (slik_smart_placement)
+		if (slik_smart_placement &&
+		    !(event->state & GDK_SHIFT_MASK))
 			{
 			gint w = gdk_screen_width();
 			gint h = gdk_screen_height();
