@@ -197,6 +197,8 @@ void list_set_font(ListData *ld, const gchar *description, GdkPixbuf *pb, gint e
 {
 	if (!ld || (!description && !pb)) return;
 
+	util_color(&r, &g, &b, &a);
+
 	ld->text_r = r;
 	ld->text_g = g;
 	ld->text_b = b;
@@ -304,7 +306,7 @@ static void list_row_clear_text(ListRowData *rd)
 		}
 
 	/* also clear the flag here */
-	rd->flag_mask = 0;
+	rd->flag_mask = -1;
 }
 
 static void list_rows_free(ListData *ld)
@@ -604,7 +606,8 @@ static void list_draw_text(ListData *ld, GdkPixbuf *pb, const gchar *text, gint
 		p = 0;
 		}
 
-	font_draw(ld->font, text, 0, x + p, y, w - p, ld->font->char_height, 0,
+	font_draw(ld->font, text, 0, x + p, y,
+		  w - p, MIN(ld->row_height - ld->text_voff, ld->font->char_height), 0,
 		  ld->text_r, ld->text_g, ld->text_b, ld->text_a,
 		  pb, ld->ui, alpha);
 }
@@ -1171,6 +1174,8 @@ static void list_back_set(gpointer data, GdkPixbuf *pb)
 		}
 
 	pixbuf_copy_fill_border_alpha(ld->overlay, ld->pixbuf,
+				      0, 0,
+				      gdk_pixbuf_get_width(ld->pixbuf), gdk_pixbuf_get_height(ld->pixbuf),
 				      ld->border_left, FALSE,
 				      ld->border_right, FALSE,
 				      ld->border_top, FALSE,
@@ -1470,8 +1475,6 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 	if (!key_list_read_int(list, "text_blue", &b)) b = 0;
 	if (!key_list_read_int(list, "text_alpha", &a)) a = 255;
 
-	util_color(&r, &g, &b, NULL);
-
 	ld = list_new(util_pixbuf_new_from_file(filename), x, y, w, h, sizeable, columns,
 		      border_top, border_right, border_bottom, border_left, center_stretch);
 	if (ld)
