@@ -260,9 +260,9 @@ static void list_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar
 		ui_edit_write_key_char(f, "text_image", text_image);
 		ui_edit_write_key_bool(f, "text_extended", ld->font->extended);
 		}
-	if (ld->font->font_description)
+	if (ld->font->text_description)
 		{
-		ui_edit_write_key_char(f, "text_font", ld->font->font_description);
+		ui_edit_write_key_char(f, "text_font", ld->font->text_description);
 		ui_edit_write_key_int(f, "text_red", ld->text_r);
 		ui_edit_write_key_int(f, "text_green", ld->text_g);
 		ui_edit_write_key_int(f, "text_blue", ld->text_b);
@@ -353,7 +353,7 @@ static gpointer list_edit_read(UIData *ui, WidgetData *wd, GList *list)
 	ll->text_image = g_strdup(ui_widget_get_data(wd, "text_image"));
 	ll->text_extended = ld->font->extended;
 
-	ll->text_font = g_strdup(ld->font->font_description);
+	ll->text_font = g_strdup(ld->font->text_description);
 	ll->text_r = ld->text_r;
 	ll->text_g = ld->text_g;
 	ll->text_b = ld->text_b;
@@ -615,7 +615,7 @@ static void list_edit_props_sync(ListDetail *dt)
 	ui_edit_entry_set(dt->text_image_entry, ui_widget_get_data(wd, "text_image"));
 	ui_edit_toggle_set(dt->text_extended_button, ld->font->extended);
 
-	ui_edit_entry_set(dt->text_font_entry, ld->font->font_description);
+	ui_edit_entry_set(dt->text_font_entry, ld->font->text_description);
 
 	ui_edit_spin_set_blocking(dt->text_font_r, ld->text_r, dt);
 	ui_edit_spin_set_blocking(dt->text_font_g, ld->text_g, dt);
@@ -1478,7 +1478,7 @@ static GtkWidget *list_edit_page_new(EditData *ed)
 	g_signal_connect(G_OBJECT(dt->text_font_entry), "changed",
 			 G_CALLBACK(list_edit_font_change_cb), pd);
 
-	ui_edit_entry_set(dt->text_font_entry, SLIK_DEFAULT_X_FONT);
+	ui_edit_entry_set(dt->text_font_entry, SLIK_DEFAULT_FONT);
 	ui_edit_spin_set(dt->text_font_r, 0);
 	ui_edit_spin_set(dt->text_font_g, 0);
 	ui_edit_spin_set(dt->text_font_b, 0);
