@@ -14,6 +14,7 @@
 #include "ui2_main.h"
 
 #include "ui2_button.h"
+#include "ui2_decal.h"
 #include "ui2_display.h"
 #include "ui2_parse.h"
 #include "ui2_skin.h"
@@ -45,10 +46,10 @@ gint slik_scale = FALSE;
 gfloat slik_scale_value = 1.0;
 gint slik_allow_shapes = TRUE;
 
-gint slik_colorshift_r = 0;
-gint slik_colorshift_g = 0;
-gint slik_colorshift_b = 0;
-gint slik_colorshift_a = 64;
+gint slik_colorshift_r = 128;
+gint slik_colorshift_g = 128;
+gint slik_colorshift_b = 128;
+gint slik_colorshift_a = 128;
 gint slik_colorshift_on = FALSE;
 
 gint slik_transparency_force = FALSE;
@@ -322,8 +323,66 @@ static void ui_skin_iconify_click_cb(ButtonData *button, const gchar *key, gpoin
 	if (ui->allow_move) ui_iconify(ui);
 }
 
+static void ui_skin_sticky_update_cb(WidgetData *wd, gpointer data, UIData *ui)
+{
+	ui_widget_draw(ui, wd, TRUE, FALSE);
+}
+
+static void ui_skin_sticky_update(UIData *ui)
+{
+	ui_widget_for_each_key_one(ui, "skin_sticky", button_type_id(),
+				   ui_skin_sticky_update_cb, NULL);
+}
+
+static gint ui_skin_sticky_status_cb(ButtonData *button, const gchar *key, gpointer data)
+{
+	UIData *ui = data;
+
+	return ui->sticky;
+}
+
+static void ui_skin_sticky_click_cb(ButtonData *button, const gchar *key, gpointer data)
+{
+	UIData *ui = data;
+
+	if (!ui->window) return;
+
+	if (debug_mode) printf("setting sticky state to %d\n", !ui->sticky);
+
+	if (ui->sticky)
+		{
+		gtk_window_unstick(GTK_WINDOW(ui->window));
+		ui->sticky = FALSE;
+		}
+	else
+		{
+		gtk_window_stick(GTK_WINDOW(ui->window));
+		ui->sticky = TRUE;
+		}
+
+	ui_skin_sticky_update(ui);
+}
+
+static gboolean ui_window_state_cb(GtkWidget *widget, GdkEventWindowState *event, gpointer data)
+{
+	UIData *ui = data;
+
+	if (event->changed_mask & GDK_WINDOW_STATE_STICKY)
+		{
+		ui->sticky = (event->new_window_state & GDK_WINDOW_STATE_STICKY);
+		ui_skin_sticky_update(ui);
+
+		if (debug_mode) printf("sticky changed: %d\n", ui->sticky);
+		}
+
+	return FALSE;
+}
+
 static void ui_add_reserved(UIData *ui)
 {
+	/* ensure decals can be recognized */
+        decal_type_init();
+
 	if (!ui_registered_key_exists(ui, "skin_toggle", button_type_id()))
 		{
 		button_register_key("skin_toggle", ui,
@@ -366,7 +425,7 @@ static void ui_add_reserved(UIData *ui)
 				     NULL, NULL,
 				     NULL, NULL);
 		}
-	if (!ui_registered_key_exists(ui, "iconify", button_type_id()))
+	if (!ui_registered_key_exists(ui, "skin_iconify", button_type_id()))
 		{
 		button_register_key("skin_iconify", ui,
 				     NULL, NULL,
@@ -374,6 +433,14 @@ static void ui_add_reserved(UIData *ui)
 				     NULL, NULL,
 				     NULL, NULL);
 		}
+	if (!ui_registered_key_exists(ui, "skin_sticky", button_type_id()))
+		{
+		button_register_key("skin_sticky", ui,
+				     ui_skin_sticky_status_cb, ui,
+				     ui_skin_sticky_click_cb, ui,
+				     NULL, NULL,
+				     NULL, NULL);
+		}
 }
 
 /*
@@ -413,36 +480,6 @@ void ui_free(UIData *ui)
 	g_free(ui);
 }
 
-static void ui_show_cb(GtkWidget *widget, gpointer data)
-{
-	UIData *ui = data;
-	gint x, y;
-
-	if (!ui->skin)
-		{
-		printf("warning: %s shown with a NULL skin\n", ui->key);
-		}
-
-	if (slik_remember_position &&
-	    ui && ui->allow_move && ui->skin &&
-	    ui_state_get(filename_from_path(ui->skin_path), ui->skin_mode_key, &x, &y, NULL, NULL))
-		{
-		/* ensure that window is at least visible */
-		if (x < 0 - ui->skin->width) x = 0;
-		if (x > gdk_screen_width()) x = gdk_screen_width() - ui->skin->width;
-		if (y < 0 - ui->skin->height) y = 0;
-		if (y > gdk_screen_height()) y = gdk_screen_height() - ui->skin->height;
-
-		if (debug_mode) printf("setting window position %d, %d\n", x, y);
-
-		gdk_window_move(ui->window->window, x, y);
-		}
-
-	/* only do this once */
-	g_signal_handlers_disconnect_matched(G_OBJECT(widget), G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
-					     0, 0, NULL, G_CALLBACK(ui_show_cb), data);
-}
-
 static void ui_hide_cb(GtkWidget *widget, gpointer data)
 {
 	UIData *ui = data;
@@ -490,12 +527,12 @@ static UIData *ui_real_new(const gchar *class, const gchar *key,
 	gtk_window_set_wmclass(GTK_WINDOW(ui->window), ui->key, ui->class);
 	gtk_window_set_title(GTK_WINDOW(ui->window), title);
 
-	g_signal_connect(G_OBJECT(ui->window), "show",
-			 G_CALLBACK(ui_show_cb), ui);
 	g_signal_connect(G_OBJECT(ui->window), "hide",
 			 G_CALLBACK(ui_hide_cb), ui);
 	g_signal_connect(G_OBJECT(ui->window), "destroy",
 			 G_CALLBACK(ui_destroy_cb), ui);
+	g_signal_connect(G_OBJECT(ui->window), "window_state_event",
+			 G_CALLBACK(ui_window_state_cb), ui);
 
 	ui->display = gtk_drawing_area_new();
 	ui_display_events_init(ui);
@@ -899,7 +936,7 @@ gint ui_geometry_get(UIData *ui, gint *x, gint *y, gint *w, gint *h)
 	    !GTK_WIDGET_REALIZED(ui->window)) return FALSE;
 
 	gdk_window_get_position(ui->window->window, &rx, &ry);
-	gdk_window_get_size(ui->window->window, &rw, &rh);
+	gtk_window_get_size(GTK_WINDOW(ui->window), &rw, &rh);
 
 	if (x) *x = rx;
 	if (y) *y = ry;
@@ -993,6 +1030,20 @@ void ui_skin_set(UIData *ui, SkinData *skin, const gchar *path, const gchar *mod
 
 		if (ui_state_get(filename_from_path(ui->skin_path), ui->skin_mode_key, &x, &y, &w, &h))
 			{
+			/* if not visible, this is the first skin, set position */
+			if (ui->window && !GTK_WIDGET_VISIBLE(ui->window) && ui->allow_move)
+				{
+				/* ensure that window is at least visible */
+				if (x < 0 - skin->width) x = 0;
+				if (x > gdk_screen_width()) x = gdk_screen_width() - skin->width;
+				if (y < 0 - skin->height) y = 0;
+				if (y > gdk_screen_height()) y = gdk_screen_height() - skin->height;
+
+				if (debug_mode) printf("setting window position %d, %d\n", x, y);
+
+				gtk_window_move(GTK_WINDOW(ui->window), x, y);
+				}
+			
 			/* only do this if the skin is actually sizeable in some way */
 			if ((skin->sizeable && ui_widget_exists(ui, "skin_size", button_type_id())) ||
 			    ui_widget_exists(ui, "skin_expand", button_type_id()) )
