@@ -148,6 +148,14 @@ void digit_type_init_edit(WidgetObjectData *od)
  */
 
 
+enum {
+	NUMBER_COLUMN_POINTER = 0,
+	NUMBER_COLUMN_IMAGE,
+	NUMBER_COLUMN_KEY,
+	NUMBER_COLUMN_COUNT
+};
+
+
 typedef struct _NumberDetail NumberDetail;
 struct _NumberDetail
 {
@@ -177,8 +185,8 @@ struct _NumberPage
 	GtkWidget *length_spin;
 	GtkWidget *rotation_spin;
 
-	GtkWidget *clist;
-	GtkWidget *pixmap;
+	GtkWidget *list;
+	GtkWidget *image;
 
 	GtkWidget *digit_key_entry;
 
@@ -402,22 +410,22 @@ static gpointer number_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, g
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 
 		nd->spin_length = ui_edit_spin_new(hbox, _("Length:"), 1, 8,  &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(number_edit_props_length_cb), nd);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(number_edit_props_length_cb), nd);
 
 		nd->spin_rotation = ui_edit_spin_new(hbox, _("Rotation:"), 0, 270, &adj);
 		GTK_ADJUSTMENT(adj)->step_increment = 90.0;
 		gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(nd->spin_rotation), TRUE);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(number_edit_props_rotation_cb), nd);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(number_edit_props_rotation_cb), nd);
 
 		nd->zero_button = ui_edit_toggle_new(vbox, _("Pad with zeros"));
-		gtk_signal_connect(GTK_OBJECT(nd->zero_button), "clicked",
-				   GTK_SIGNAL_FUNC(number_edit_props_alter_cb), nd);
+		g_signal_connect(G_OBJECT(nd->zero_button), "clicked",
+				 G_CALLBACK(number_edit_props_alter_cb), nd);
 
 		nd->center_button = ui_edit_toggle_new(vbox, _("Center"));
-		gtk_signal_connect(GTK_OBJECT(nd->center_button), "clicked",
-				   GTK_SIGNAL_FUNC(number_edit_props_alter_cb), nd);
+		g_signal_connect(G_OBJECT(nd->center_button), "clicked",
+				 G_CALLBACK(number_edit_props_alter_cb), nd);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 
@@ -535,12 +543,16 @@ static void number_edit_page_sync(NumberPage *pd, DigitListData *dd)
 	ui_edit_entry_set(pd->image_entry, dd->image);
 }
 
-static void number_edit_page_clist_cb(GtkWidget *clist, gint row, gint col, GdkEvent *event, gpointer data)
+static void number_edit_page_list_cb(GtkTreeSelection *selection, gpointer data)
 {
 	NumberPage *pd = data;
 	DigitListData *dd;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
-	dd = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	gtk_tree_model_get(store, &iter, NUMBER_COLUMN_POINTER, &dd, -1);
 	number_edit_page_sync(pd, dd);
 }
 
@@ -578,16 +590,16 @@ static GtkWidget *number_edit_page_new(EditData *ed)
 	GtkWidget *sep;
 	GtkObject *adj;
 	NumberPage *pd;
-	gchar *titles[] = { _("Image"), _("Key"), NULL };
+	GtkListStore *store;
 
 	pd = g_new0(NumberPage, 1);
 	pd->ed = ed;
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_object_set_data(GTK_OBJECT(hbox), "page", pd);
-	gtk_signal_connect(GTK_OBJECT(hbox), "destroy",
-			   GTK_SIGNAL_FUNC(number_edit_page_destroy_cb), pd);
+	g_object_set_data(G_OBJECT(hbox), "page", pd);
+	g_signal_connect(G_OBJECT(hbox), "destroy",
+			 G_CALLBACK(number_edit_page_destroy_cb), pd);
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -605,20 +617,20 @@ static GtkWidget *number_edit_page_new(EditData *ed)
 
 	pd->zeros_button = ui_edit_toggle_new(vbox, _("Pad with zeros"));
 	pd->center_button = ui_edit_toggle_new(vbox, _("Center"));
-	gtk_signal_connect(GTK_OBJECT(pd->center_button), "clicked",
-			   GTK_SIGNAL_FUNC(number_edit_page_center_cb), pd);
+	g_signal_connect(G_OBJECT(pd->center_button), "clicked",
+			 G_CALLBACK(number_edit_page_center_cb), pd);
 
 	pd->digit_id_entry = ui_edit_entry_new(vbox, _("Digit key:"));
-	gtk_signal_connect(GTK_OBJECT(pd->digit_id_entry), "changed",
-			   GTK_SIGNAL_FUNC(number_edit_page_digit_cb), pd);
+	g_signal_connect(G_OBJECT(pd->digit_id_entry), "changed",
+			 G_CALLBACK(number_edit_page_digit_cb), pd);
 	pd->image_entry = ui_edit_path_entry_new(vbox, _("Image:"), "SLIK_number_image");
-	pd->pixmap = ui_edit_pixmap_new(vbox);
-	ui_edit_path_entry_connect_pixmap(pd->image_entry, pd->pixmap);
+	pd->image = ui_edit_image_new(vbox);
+	ui_edit_path_entry_connect_image(pd->image_entry, pd->image);
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(number_edit_page_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(number_edit_page_add_cb), pd);
 	gtk_widget_show(button);
 
 	sep = gtk_hseparator_new();
@@ -630,13 +642,17 @@ static GtkWidget *number_edit_page_new(EditData *ed)
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_end(GTK_BOX(frame), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(number_edit_page_digit_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(number_edit_page_digit_add_cb), pd);
 	gtk_widget_show(button);
 
-	pd->clist = ui_edit_clist_new(hbox, titles, 2);
-	gtk_signal_connect(GTK_OBJECT(pd->clist), "select_row",
-			   GTK_SIGNAL_FUNC(number_edit_page_clist_cb), pd);
+	store = gtk_list_store_new(3, G_TYPE_POINTER, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+	pd->list = ui_edit_list_new(hbox, store,
+				    G_CALLBACK(number_edit_page_list_cb), pd);
+	g_object_unref(store);
+
+	ui_edit_list_add_column(pd->list, _("Image"), NUMBER_COLUMN_IMAGE, TRUE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Key"), NUMBER_COLUMN_KEY, FALSE, FALSE);
 
 	/* hacky, but it works */
 	ui_edit_widget_id_list_set_page(ed->widget_id_list, digit_type_id(), hbox);
@@ -650,15 +666,22 @@ static void number_edit_page_add(GtkWidget *widget, gpointer data)
 {
 	DigitListData *dd = data;
 	NumberPage *pd;
-	gchar *buf[3];
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GdkPixbuf *pixbuf;
 
-	pd = gtk_object_get_data(GTK_OBJECT(widget), "page");
+	pd = g_object_get_data(G_OBJECT(widget), "page");
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(pd->list)));
 
-	buf[0] = "";
-	buf[1] = dd->key;
-	buf[2] = NULL;
+	pixbuf = ui_edit_list_pixbuf_from_file(dd->image);
 
-	ui_edit_clist_append(pd->clist, buf, dd->image, dd);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   NUMBER_COLUMN_POINTER, dd,
+			   NUMBER_COLUMN_IMAGE, pixbuf,
+			   NUMBER_COLUMN_KEY, dd->key, -1);
+
+	if (pixbuf) gdk_pixbuf_unref(pixbuf);
 }
 
 void number_type_init_edit(WidgetObjectData *od)
