@@ -1,6 +1,6 @@
 /*
  * (SLIK) SimpLIstic sKin functions
- * (C) 2002 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -31,20 +31,28 @@
  *-------------
  */
 
-static void skin_back_setup(SkinData *skin, UIData *ui)
+static void skin_back_setup(SkinData *skin)
 {
 	GdkPixbuf *s;
 	GdkPixbuf *d;
 	gint w, h;
 
 	if (!skin->real_overlay) return;
-	if (skin->overlay && !skin->sizeable && !skin->has_border &&
-	    skin->width == gdk_pixbuf_get_width(skin->overlay) &&
-	    skin->height == gdk_pixbuf_get_height(skin->overlay) ) return;
 
-	if (skin->overlay) gdk_pixbuf_unref(skin->overlay);
-	skin->overlay = gdk_pixbuf_new(GDK_COLORSPACE_RGB, gdk_pixbuf_get_has_alpha(skin->real_overlay), 8,
-				       skin->width, skin->height);
+	if (skin->overlay &&
+	    (skin->width != gdk_pixbuf_get_width(skin->overlay) ||
+	     skin->height != gdk_pixbuf_get_height(skin->overlay)))
+		{
+		gdk_pixbuf_unref(skin->overlay);
+		skin->overlay = NULL;
+		}
+
+	if (!skin->overlay)
+		{
+		skin->overlay = gdk_pixbuf_new(GDK_COLORSPACE_RGB,
+					       gdk_pixbuf_get_has_alpha(skin->real_overlay), 8,
+					       skin->width, skin->height);
+		}
 
 	s = skin->real_overlay;
 	w = gdk_pixbuf_get_width(s);
@@ -54,43 +62,14 @@ static void skin_back_setup(SkinData *skin, UIData *ui)
 
 	if (skin->has_border)
 		{
-		gint n, m;
-		/* corners */
-		pixbuf_copy_area(s, 0, 0,
-				 d, 0, 0,
-				 skin->border_left, skin->border_top, TRUE);
-		pixbuf_copy_area(s, w - skin->border_right, 0,
-				 d, skin->width - skin->border_right, 0,
-				 skin->border_right, skin->border_top, TRUE);
-		pixbuf_copy_area(s, 0, h - skin->border_bottom,
-				 d, 0, skin->height - skin->border_bottom,
-				 skin->border_left, skin->border_bottom, TRUE);
-		pixbuf_copy_area(s, w - skin->border_right, h - skin->border_bottom,
-				 d, skin->width - skin->border_right, skin->height - skin->border_bottom,
-				 skin->border_right, skin->border_bottom, TRUE);
-
-		/* sides */
-		n = skin->border_top + skin->border_bottom;	/* vert borders tot. */
-		m = skin->border_left + skin->border_right;	/* horz borders tot. */
-
-		pixbuf_copy_fill(s, 0, skin->border_top, skin->border_left, h - n,
-				 d, 0, skin->border_top, skin->border_left, skin->height - n,
-				 skin->border_left_stretch, TRUE);
-		pixbuf_copy_fill(s, w - skin->border_right, skin->border_top, skin->border_right, h - n,
-				 d, skin->width - skin->border_right, skin->border_top, skin->border_right, skin->height - n,
-				 skin->border_right_stretch, TRUE);
-
-		pixbuf_copy_fill(s, skin->border_left, 0, w - m, skin->border_top,
-				 d, skin->border_left, 0, skin->width - m, skin->border_top,
-				 skin->border_top_stretch, TRUE);
-		pixbuf_copy_fill(s, skin->border_left, h - skin->border_bottom, w - m, skin->border_bottom,
-				 d, skin->border_left, skin->height - skin->border_bottom, skin->width - m, skin->border_bottom,
-				 skin->border_bottom_stretch, TRUE);
-
-		/* center field */
-		pixbuf_copy_fill(s, skin->border_left, skin->border_top, w - m, h - n,
-				 d, skin->border_left, skin->border_top, skin->width - m, skin->height - n,
-				 skin->stretch, TRUE);
+		pixbuf_copy_fill_border(s, d,
+					0, 0,
+					gdk_pixbuf_get_width(d), gdk_pixbuf_get_height(d),
+					skin->border_left, skin->border_left_stretch,
+					skin->border_right, skin->border_right_stretch,
+					skin->border_top, skin->border_top_stretch,
+					skin->border_bottom, skin->border_bottom_stretch,
+					skin->stretch, TRUE);
 		}
 	else
 		{
@@ -99,7 +78,7 @@ static void skin_back_setup(SkinData *skin, UIData *ui)
 				 skin->stretch, TRUE);
 		}
 
-	if (skin->mask_buffer) gdk_bitmap_unref(skin->mask_buffer);
+	if (skin->mask_buffer) g_object_unref(skin->mask_buffer);
 	skin->mask_buffer = NULL;
 	if (skin->mask)
 		{
@@ -111,6 +90,37 @@ static void skin_back_setup(SkinData *skin, UIData *ui)
 		}
 }
 
+static void skin_back_pass2(SkinData *skin, UIData *ui)
+{
+	guint8 alpha;
+
+	if (!skin->real_overlay || !skin->overlay) return;
+
+	alpha =  (slik_transparency_force) ? slik_transparency_force_a : 255;
+
+	if (skin->has_border)
+		{
+		pixbuf_copy_fill_border_alpha(skin->real_overlay, skin->overlay,
+					      0, 0,
+					      gdk_pixbuf_get_width(skin->overlay), gdk_pixbuf_get_height(skin->overlay),
+					      skin->border_left, skin->border_left_stretch,
+					      skin->border_right, skin->border_right_stretch,
+					      skin->border_top, skin->border_top_stretch,
+					      skin->border_bottom, skin->border_bottom_stretch,
+					      skin->stretch, alpha);
+		}
+	else
+		{
+		gint w, h;
+
+		w = gdk_pixbuf_get_width(skin->real_overlay);
+		h = gdk_pixbuf_get_height(skin->real_overlay);
+		pixbuf_copy_fill_alpha(skin->real_overlay, 0, 0, w, h,
+				       skin->overlay, 0, 0, skin->width, skin->height,
+				       skin->stretch, alpha);
+		}
+}
+
 /*
  *-------------
  * skin side keys
@@ -352,16 +362,16 @@ void skin_free(SkinData *skin)
 
 	if (skin->overlay) gdk_pixbuf_unref(skin->overlay);
 	if (skin->pixbuf) gdk_pixbuf_unref(skin->pixbuf);
-	if (skin->buffer) gdk_pixmap_unref(skin->buffer);
+	if (skin->buffer) g_object_unref(skin->buffer);
 	if (skin->mask) gdk_pixbuf_unref(skin->mask);
-	if (skin->mask_buffer) gdk_bitmap_unref(skin->mask_buffer);
+	if (skin->mask_buffer) g_object_unref(skin->mask_buffer);
 
 	if (skin->real_overlay) gdk_pixbuf_unref(skin->real_overlay);
 
 	if (skin->focus_overlay) gdk_pixbuf_unref(skin->focus_overlay);
 
 	if (skin->scratch_pixbuf) gdk_pixbuf_unref(skin->scratch_pixbuf);
-	if (skin->scratch_pixmap) gdk_pixmap_unref(skin->scratch_pixmap);
+	if (skin->scratch_pixmap) g_object_unref(skin->scratch_pixmap);
 
 	g_free(skin->background_filename);
 	g_free(skin->background_mask_filename);
@@ -396,7 +406,7 @@ void skin_get_scratch(SkinData *skin, gint w, gint h, GdkPixbuf **pixbuf, GdkPix
 		if (skin->scratch_pixbuf) gdk_pixbuf_unref(skin->scratch_pixbuf);
 		skin->scratch_pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, w, h);
 
-		if (skin->scratch_pixmap) gdk_pixmap_unref(skin->scratch_pixmap);
+		if (skin->scratch_pixmap) g_object_unref(skin->scratch_pixmap);
 		skin->scratch_pixmap = gdk_pixmap_new(skin->ui->display->window, w, h, -1);
 		}
 
@@ -422,29 +432,35 @@ UIData *skin_get_ui(SkinData *skin)
 
 static void skin_sync_back_on_widgets(SkinData *skin, UIData *ui)
 {
-	GList *work;
+	gint priority;
 
-	work = skin->widget_list;
-	while(work)
+	for (priority = UI_WIDGET_PRIORITY_HIGH; priority >= 0; priority--)
 		{
-		WidgetData *wd = work->data;
-		work = work->next;
-		ui_widget_sync_back(ui, wd);
+		GList *work;
+
+		work = skin->widget_list;
+		while (work)
+			{
+			WidgetData *wd = work->data;
+			work = work->next;
+
+			if (wd->od->priority == priority) ui_widget_sync_back(ui, wd);
+			}
 		}
 }
 
 void skin_sync_back(SkinData *skin, UIData *ui)
 {
-	GdkPixbuf *pb;
+	gint pass2 = FALSE;
 
-	if (!skin || !skin->pixbuf) return;
-
-	pb = skin->pixbuf;
+	if (!skin || !skin->overlay || !skin->pixbuf) return;
 
 	if (ui->back_func &&
 	    (gdk_pixbuf_get_has_alpha(skin->overlay) || slik_transparency_force) &&
-	    ui->back_func(ui, pb, ui->back_data))
+	    ui->back_func(ui, skin->overlay, ui->back_data))
 		{
+		pass2 = TRUE;
+#if 0
 		if (slik_transparency_force)
 			{
 			pixbuf_copy_area_alpha(skin->overlay, 0, 0, pb, 0, 0, skin->width, skin->height,
@@ -454,6 +470,7 @@ void skin_sync_back(SkinData *skin, UIData *ui)
 			{
 			pixbuf_copy_area_alpha(skin->overlay, 0, 0, pb, 0, 0, skin->width, skin->height, 255);
 			}
+#endif
 		}
 	else if (skin->transparent || slik_transparency_force)
 		{
@@ -468,8 +485,10 @@ void skin_sync_back(SkinData *skin, UIData *ui)
 			gdk_window_get_position(ui->display->window, &x, &y);
 			}
 
-		util_pixbuf_fill_from_root_window(pb, x, y, FALSE);
+		util_pixbuf_fill_from_root_window(skin->overlay, x, y, FALSE);
 
+		pass2 = TRUE;
+#if 0
 		if (slik_transparency_force)
 			{
 			pixbuf_copy_area_alpha(skin->overlay, 0, 0, pb, 0, 0, skin->width, skin->height,
@@ -479,34 +498,44 @@ void skin_sync_back(SkinData *skin, UIData *ui)
 			{
 			pixbuf_copy_area_alpha(skin->overlay, 0, 0, pb, 0, 0, skin->width, skin->height, 255);
 			}
+#endif
 		}
+#if 0
 	else
 		{
 		pixbuf_copy_area(skin->overlay, 0, 0, pb, 0, 0, skin->width, skin->height, FALSE);
 		}
+#endif
+
+	if (pass2) skin_back_pass2(skin, ui);
 
 	skin_sync_back_on_widgets(skin, ui);
+	pixbuf_copy_area(skin->overlay, 0, 0, skin->pixbuf, 0, 0, skin->width, skin->height, FALSE);
 }
 
 void skin_set_underlay(SkinData *skin, UIData *ui, GdkPixbuf *pb)
 {
 	if (!skin || !skin->pixbuf || !pb) return;
 
-	pixbuf_copy_area(pb, 0, 0, skin->pixbuf, 0, 0, skin->width, skin->height, FALSE);
+	skin_back_setup(skin);
+	pixbuf_copy_area(pb, 0, 0, skin->overlay, 0, 0, skin->width, skin->height, FALSE);
+#if 0
 	pixbuf_copy_area_alpha(skin->overlay, 0, 0, skin->pixbuf, 0, 0, skin->width, skin->height, 255);
-
+#endif
+	skin_back_pass2(skin, ui);
 	skin_sync_back_on_widgets(skin, ui);
+	pixbuf_copy_area(skin->overlay, 0, 0, skin->pixbuf, 0, 0, skin->width, skin->height, FALSE);
 }
 
 void skin_sync_buffer(SkinData *skin, UIData *ui)
 {
 	if (!skin) return;
 
-	skin_back_setup(skin, ui);
+	skin_back_setup(skin);
 
 	if (!GTK_WIDGET_REALIZED(ui->display)) gtk_widget_realize(ui->display);
 
-	if (skin->buffer) gdk_pixmap_unref(skin->buffer);
+	if (skin->buffer) g_object_unref(skin->buffer);
 	skin->buffer = gdk_pixmap_new(ui->display->window, skin->width, skin->height, -1);
 
 	if (skin->pixbuf) gdk_pixbuf_unref(skin->pixbuf);
