@@ -76,8 +76,8 @@ FontData *font_new(GdkPixbuf *pb, gint extended)
 	font->extended = extended;
 	font->fill = TRUE;
 
+	font->text_description = NULL;
 	font->font_description = NULL;
-	font->font = NULL;
 
 	width = gdk_pixbuf_get_width(font->overlay);
 	height = gdk_pixbuf_get_height(font->overlay);
@@ -116,6 +116,167 @@ FontData *font_new_from_file(const gchar *file, gint extended)
 	return font_new(pb, extended);
 }
 
+static gchar *x_font_find_field(const gchar *text, gint n)
+{
+	const gchar *ptr;
+	gint l;
+
+	ptr = text;
+	while (n >= 0 && *ptr != '\0')
+		{
+		if (*ptr == '-') n--;
+		ptr++;
+		}
+
+	if (n >= 0 || *ptr == '*') return NULL;
+
+	l = 0;
+	while (ptr[l] != '\0' && ptr[l] != '-') l++;
+
+	if (l < 1) return NULL;
+
+	return g_strndup(ptr, l);
+}
+
+/*
+ * This is to pull the dpi used by pango, and scale the point size so that
+ * the pixel size is always equal to that on a 96 dpi monitor
+ */
+static gint x_font_convert_points_by_dpi(gint points)
+{
+	GtkSettings *settings;
+	GObjectClass *klass;
+	gint dpi = -1;
+
+	settings = gtk_settings_get_default();
+	klass = G_OBJECT_CLASS(GTK_SETTINGS_GET_CLASS(settings));
+	if (g_object_class_find_property(klass, "gtk-xft-dpi"))
+		{
+		static gint debugged = FALSE;
+		int int_dpi;
+
+		g_object_get(settings, "gtk-xft-dpi", &int_dpi, NULL);
+		dpi = int_dpi / PANGO_SCALE;
+
+		if (debug_mode && !debugged)
+			{
+			printf("pango is using a dpi of %d\n", dpi);
+			debugged = TRUE;
+			}
+		}
+
+	if (dpi < 25)
+		{
+		static gint warned = FALSE;
+		gint fallback_dpi = 96;
+
+		/* not set or invalid, just assume the default */
+
+		if (!warned)
+			{
+			if (dpi == -1)
+				{
+				printf("pango dpi unknown, assuming %d\n", fallback_dpi);
+				}
+			else
+				{
+				printf("pango dpi reported as %d ignored, assuming %d\n", dpi, fallback_dpi);
+				}
+			warned = TRUE;
+			}
+
+		dpi = fallback_dpi;
+		}
+
+	return points * 96 / dpi;
+}
+
+static gchar *x_font_convert_to_pango_string(const gchar *description)
+{
+	gchar *result;
+	GString *str = NULL;
+	const gchar *ptr;
+	gint c = 0;
+	gchar *family;
+	gchar *weight;
+	gchar *slant;
+	gchar *size;
+	gint space;
+
+	if (!description) return NULL;
+
+	ptr = description;
+	if (*ptr != '-') return NULL;
+	while (*ptr != '\0')
+		{
+		if (*ptr == '-') c++;
+		ptr++;
+		}
+
+	if (c != 14) return NULL;
+
+	family = x_font_find_field(description, 1);
+	weight = x_font_find_field(description, 2);
+	slant  = x_font_find_field(description, 3);
+	size   = x_font_find_field(description, 6);
+
+	str = g_string_new("");
+	space = FALSE;
+
+	g_string_append(str, (family && strlen(family) > 0) ? family : "Sans");
+	space = TRUE;
+
+	if (weight)
+		{
+		if (space) g_string_append(str, " ");
+		g_string_append(str, weight);
+		space = TRUE;
+		}
+
+	if (slant &&
+	    (strcasecmp(slant, "i") == 0 || strcasecmp(slant, "o") == 0))
+		{
+		if (space) g_string_append(str, " ");
+		g_string_append(str, "italic");
+		space = TRUE;
+		}
+
+	if (size)
+		{
+		gint s;
+
+		s = strtol(size, NULL, 10);
+		if (s < 8) s = 10;
+
+		/* pango size is in points, we are coming from pixels, try to convert
+		 * (there is no exact correlation? but this seems to work ok - for me.)
+		 */
+		s = s * 75 / 96;
+
+		if (space) g_string_append(str, " ");
+		g_string_append_printf(str, "%d", s);
+		}
+	else
+		{
+		printf("warning: font description contains no size information [%s]\n", description);
+		}
+
+	g_free(family);
+	g_free(weight);
+	g_free(slant);
+	g_free(size);
+
+	result = str->str;
+	g_string_free(str, FALSE);
+
+	if (debug_mode)
+		{
+		printf("Pango font description \"%s\"\n   auto converted from \"%s\"\n", result, description);
+		}
+
+	return result;
+}
+
 FontData *font_new_from_x(const gchar *description)
 {
 	FontData *font;
@@ -128,27 +289,65 @@ FontData *font_new_from_x(const gchar *description)
 	font->extended = FALSE;
 	font->fill = FALSE;
 
-	font->font_description = g_strdup(description);
+	font->text_description = g_strdup(description);
+	font->font_description = NULL;
 
-	if (font->font_description) font->font = gdk_fontset_load(font->font_description);
-	if (!font->font)
+	if (font->text_description)
 		{
-		printf("Warning: unable to load X font \"%s\"\n", font->font_description);
-		font->font = gdk_fontset_load(SLIK_DEFAULT_X_FONT);
+		gchar *converted;
+
+		converted = x_font_convert_to_pango_string(font->text_description);
+		if (converted)
+			{
+			font->font_description = pango_font_description_from_string(converted);
+			g_free(converted);
+			}
+		else
+			{
+			font->font_description = pango_font_description_from_string(font->text_description);
+			}
 		}
-	if (!font->font) font->font = gdk_fontset_load("fixed");
-
-	if (font->font)
+	if (!font->font_description)
 		{
-		gdk_font_ref(font->font);
+		printf("Warning: unable to load font \"%s\"\n", font->text_description);
+		font->font_description = pango_font_description_from_string(SLIK_DEFAULT_FONT);
+		}
+	if (!font->font_description)
+		{
+		font->font_description = pango_font_description_from_string("fixed");
+		}
+
+	if (font->font_description)
+		{
+		PangoContext *context;
+		PangoFontMetrics *metrics;
+		gint points;
+
+		/* Convert point size based on dpi used by pango,
+		 * so that pixel size is always equivelent regardless of dpi setting.
+		 */
+		points = pango_font_description_get_size(font->font_description);
+		points = x_font_convert_points_by_dpi(points);
+		if (points > 0) pango_font_description_set_size(font->font_description, points);
+
+		context = gdk_pango_context_get_for_screen(gdk_screen_get_default());
+		metrics = pango_context_get_metrics(context, font->font_description,
+						    pango_context_get_language(context));
+
+		font->char_height = PANGO_PIXELS(pango_font_metrics_get_ascent(metrics) +
+						 pango_font_metrics_get_descent(metrics));
+
+		pango_font_metrics_unref(metrics);
+		g_object_unref(context);
 		}
 	else
 		{
 		printf("Warning: unable to load any font\n");
+
+		font->char_height = 1;
 		}
 
 	font->char_width = 1;
-	font->char_height = font->font->ascent + font->font->descent;
 
 	font->ref = 1;
 
@@ -161,8 +360,8 @@ static void font_free(FontData *font)
 
 	if (font->overlay) gdk_pixbuf_unref(font->overlay);
 
-	if (font->font) gdk_font_unref(font->font);
-	g_free(font->font_description);
+	if (font->font_description) pango_font_description_free(font->font_description);
+	g_free(font->text_description);
 
 	g_free(font);
 }
@@ -318,11 +517,24 @@ static void pixbuf_font_rotate_0(guchar *s_pix, gint srs, gint s_step, gint s_al
 			{
 			if (*sp)
 				{
+#if 0
 				*dp = (r * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (g * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (b * a + *dp * (256-a)) >> 8;
+#endif
+				guint8 asub;
+
+				asub = a * sp[0] / 255;
+				*dp = (r * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[1] / 255;
+				*dp = (g * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[2] / 255;
+				*dp = (b * asub + *dp * (256-asub)) >> 8;
+
 				dp++;
 				if (d_alpha) dp++;
 				}
@@ -352,11 +564,24 @@ static void pixbuf_font_rotate_180(guchar *s_pix, gint srs, gint s_step, gint s_
 			{
 			if (*sp)
 				{
+#if 0
 				*dp = (r * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (g * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (b * a + *dp * (256-a)) >> 8;
+#endif
+				guint8 asub;
+
+				asub = a * sp[0] / 255;
+				*dp = (r * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[1] / 255;
+				*dp = (g * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[2] / 255;
+				*dp = (b * asub + *dp * (256-asub)) >> 8;
+
 				dp -= 2;
 				}
 
@@ -383,11 +608,24 @@ static void pixbuf_font_rotate_90(guchar *s_pix, gint srs, gint s_step, gint s_a
 			{
 			if (*sp)
 				{
+#if 0
 				*dp = (r * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (g * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (b * a + *dp * (256-a)) >> 8;
+#endif
+				guint8 asub;
+
+				asub = a * sp[0] / 255;
+				*dp = (r * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[1] / 255;
+				*dp = (g * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[2] / 255;
+				*dp = (b * asub + *dp * (256-asub)) >> 8;
+
 				dp -= 2;
 				}
 
@@ -414,11 +652,24 @@ static void pixbuf_font_rotate_270(guchar *s_pix, gint srs, gint s_step, gint s_
 			{
 			if (*sp)
 				{
+#if 0
 				*dp = (r * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (g * a + *dp * (256-a)) >> 8;
 				dp++;
 				*dp = (b * a + *dp * (256-a)) >> 8;
+#endif
+				guint8 asub;
+
+				asub = a * sp[0] / 255;
+				*dp = (r * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[1] / 255;
+				*dp = (g * asub + *dp * (256-asub)) >> 8;
+				dp++;
+				asub = a * sp[2] / 255;
+				*dp = (b * asub + *dp * (256-asub)) >> 8;
+
 				dp++;
 				if (d_alpha) dp++;
 				}
@@ -508,6 +759,7 @@ static void font_draw_string_x(FontData *font, const gchar *text, gint offset,
 			       guint8 r, guint8 g, guint8 b, guint8 a,
 			       GdkPixbuf *pb, UIData *ui)
 {
+	PangoLayout *layout;
 	GdkGC *gc;
 	GdkPixbuf *buffer_pixbuf;
 	GdkPixmap *buffer_pixmap;
@@ -526,17 +778,24 @@ static void font_draw_string_x(FontData *font, const gchar *text, gint offset,
 	rect.width = w;
 	rect.height = h;
 	gdk_gc_set_clip_rectangle(gc, &rect);
+#if 0
 	gdk_draw_string(buffer_pixmap, font->font, gc, 0 - offset, font->font->ascent, text);
+#endif
+	layout = gtk_widget_create_pango_layout(ui->display, NULL);
+	pango_layout_set_font_description(layout, font->font_description);
+	pango_layout_set_text(layout, text, -1);
+	gdk_draw_layout(buffer_pixmap, gc, 0 - offset, 0, layout);
+	g_object_unref(G_OBJECT(layout));
 
 	gdk_pixbuf_get_from_drawable(buffer_pixbuf, buffer_pixmap,
-		       		     gdk_window_get_colormap(ui->display->window),
+		       		     gdk_drawable_get_colormap(ui->display->window),
 				     0, 0, 0, 0, w, h);
 
 	pixbuf_copy_font(buffer_pixbuf, 0, 0,
 			 pb, x, y, w, h, rotation,
 			 r, g, b, a);
 
-	gdk_gc_unref(gc);
+	g_object_unref(gc);
 }
 
 void font_draw(FontData *font, const gchar *text, gint offset,
@@ -559,7 +818,7 @@ void font_draw(FontData *font, const gchar *text, gint offset,
 		font_draw_string(font, text, offset,
 				 x, y, w, h, rotation, pb, alpha);
 		}
-	else if (font->font)
+	else if (font->font_description)
 		{
 		font_draw_string_x(font, text, offset,
 				   x, y, w, h, rotation,
@@ -568,7 +827,7 @@ void font_draw(FontData *font, const gchar *text, gint offset,
 		}
 	else
 		{
-		printf("ui2_text.c warning: attempt to draw font will NULL overlay and X font\n");
+		printf("ui2_text.c warning: attempt to draw font with NULL overlay and font description\n");
 		}
 }
 
@@ -580,9 +839,25 @@ gint font_string_length(FontData *font, const gchar *text)
 		{
 		return strlen(text) * font->char_width;
 		}
-	if (font->font)
+	if (font->font_description)
 		{
-		return gdk_string_width(font->font, text);
+		gint width;
+
+		PangoLayout *layout;
+		PangoContext *context;
+
+		context = gdk_pango_context_get_for_screen(gdk_screen_get_default());
+
+		layout = pango_layout_new(context);
+		pango_layout_set_font_description(layout, font->font_description);
+		pango_layout_set_text(layout, text, -1);
+
+		pango_layout_get_pixel_size(layout, &width, NULL);
+
+		g_object_unref(context);
+		g_object_unref(layout);
+
+		return width;
 		}
 
 	return 0;
@@ -821,6 +1096,8 @@ void text_set_color(TextData *text, guint8 r, guint8 g, guint8 b, guint8 a)
 {
 	if (!text) return;
 
+	util_color(&r, &g, &b, &a);
+
 	text->r = r;
 	text->g = g;
 	text->b = b;
@@ -1152,8 +1429,6 @@ static WidgetData *text_parse(SkinData *skin, GList *list, const gchar *skin_dir
 	if (!key_list_read_int(list, "blue", &b)) b = 0;
 	if (!key_list_read_int(list, "alpha", &a)) a = 255;
 
-	util_color(&r, &g, &b, NULL);
-
 	if (filename)
 		{
 		text = text_new_from_file(filename, x, y, width, sizeable, rotation, extended);
