@@ -13,7 +13,7 @@
 #define UI2_TEXT_H
 
 
-#define SLIK_DEFAULT_X_FONT "-*-*-medium-*-*-*-10-*-*-*-*-*-*-*"
+#define SLIK_DEFAULT_FONT "Sans 12"
 
 
 typedef struct _FontData FontData;
@@ -25,8 +25,8 @@ struct _FontData
 	gint extended;	/* to support chars above 128 */
 	gint fill;	/* pad image fonts with spaces at end */
 
-	gchar *font_description;
-	GdkFont *font;
+	gchar *text_description;
+	PangoFontDescription *font_description;
 
 	gint ref;	/* ref count */
 };
