@@ -84,7 +84,7 @@ static void font_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar
 		}
 	else
 		{
-		ui_edit_write_key_char(f, "description", font->font_description);
+		ui_edit_write_key_char(f, "description", font->text_description);
 		}
 }
 
@@ -153,7 +153,7 @@ static gpointer font_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 		}
 
 	ui_edit_toggle_set(fd->extended_button, font->extended);
-	ui_edit_entry_set(fd->font_entry, font->font_description);
+	ui_edit_entry_set(fd->font_entry, font->text_description);
 
 	return fd;
 }
@@ -279,17 +279,24 @@ static void text_edit_write(FILE *f, WidgetData *wd, SkinData *skin, const gchar
 
 		g_free(image);
 		}
-	else if (font_id)
-		{
-		ui_edit_write_key_char(f, "font", font_id);
-		}
 	else
 		{
-		ui_edit_write_key_char(f, "description", text->font->font_description);
-		ui_edit_write_key_int(f, "red", (gint)text->r);
-		ui_edit_write_key_int(f, "green", (gint)text->g);
-		ui_edit_write_key_int(f, "blue", (gint)text->b);
-		ui_edit_write_key_int(f, "alpha", (gint)text->a);
+		if (font_id)
+			{
+			ui_edit_write_key_char(f, "font", font_id);
+			}
+		else
+			{
+			ui_edit_write_key_char(f, "description", text->font->text_description);
+			}
+
+		if (!font_id || !text->font->overlay)
+			{
+			ui_edit_write_key_int(f, "red", (gint)text->r);
+			ui_edit_write_key_int(f, "green", (gint)text->g);
+			ui_edit_write_key_int(f, "blue", (gint)text->b);
+			ui_edit_write_key_int(f, "alpha", (gint)text->a);
+			}
 		}
 
 	ui_edit_write_key_int(f, "x", text->x);
@@ -522,7 +529,7 @@ static gpointer text_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 	ui_edit_spin_set_blocking(td->spin_width, font_rotation_vertical(text->rotation) ? text->height : text->width, td);
 	ui_edit_spin_set_blocking(td->spin_rotation, text->rotation, td);
 
-	ui_edit_entry_set(td->font_entry, text->font->font_description);
+	ui_edit_entry_set(td->font_entry, text->font->text_description);
 
 	ui_edit_spin_set_blocking(td->red_spin, text->r, td);
 	ui_edit_spin_set_blocking(td->green_spin, text->g, td);
@@ -804,7 +811,7 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 	ui_edit_spin_set(pd->green_spin, 0);
 	ui_edit_spin_set(pd->blue_spin, 0);
 	ui_edit_spin_set(pd->alpha_spin, 255);
-	gtk_entry_set_text(GTK_ENTRY(pd->font_entry), SLIK_DEFAULT_X_FONT);
+	gtk_entry_set_text(GTK_ENTRY(pd->font_entry), SLIK_DEFAULT_FONT);
 
 	return hbox;
 }
