@@ -45,18 +45,23 @@ void util_size(gint *n)
 		}
 }
 
-void util_color(gint *r, gint *g, gint *b, gint *a)
+void util_color(guint8 *r, guint8 *g, guint8 *b, guint8 *a)
 {
-	if (slik_colorshift_on)
+	if (slik_colorshift_on && r && g && b)
 		{
-		guint8 a = slik_colorshift_a;
-		if (r) *r = (*r * (256 - a) + slik_colorshift_r * a) >> 8;
-		if (g) *g = (*g * (256 - a) + slik_colorshift_g * a) >> 8;
-		if (b) *b = (*b * (256 - a) + slik_colorshift_b * a) >> 8;
+		gint saturation = (*r + *g + *b) / 3;
+
+		*r = pixel_shift(*r, saturation, slik_colorshift_r, slik_colorshift_a);
+		*g = pixel_shift(*g, saturation, slik_colorshift_g, slik_colorshift_a);
+		*b = pixel_shift(*b, saturation, slik_colorshift_b, slik_colorshift_a);
 		}
-	if ((a) && slik_transparency_force)
+	if (slik_transparency_force && a)
 		{
-		*a = (*a * slik_transparency_force_a) >> 8;
+		gint t;
+
+		t = (gint)*a;
+		t = (t * 3 + t * slik_transparency_force_a / 255) / 4;
+		*a = t;
 		}
 }
 
@@ -119,8 +124,8 @@ GdkPixbuf *util_size_pixbuf(GdkPixbuf *pb, gint apply_adjustments)
 
 	if (pb && apply_adjustments && slik_colorshift_on)
 		{
-		pixbuf_draw_rect_fill(pb, 0, 0, gdk_pixbuf_get_width(pb), gdk_pixbuf_get_height(pb),
-				      slik_colorshift_r, slik_colorshift_g, slik_colorshift_b, slik_colorshift_a);
+		pixbuf_draw_rect_shift(pb, 0, 0, gdk_pixbuf_get_width(pb), gdk_pixbuf_get_height(pb),
+				       slik_colorshift_r, slik_colorshift_g, slik_colorshift_b, slik_colorshift_a);
 		}
 
 	return pb;
@@ -314,10 +319,10 @@ gint util_pixbuf_fill_from_root_window(GdkPixbuf *pb, gint x, gint y, gint get_a
 
 	if (w < 1 || h < 1) return TRUE;
 
-	rootwindow = GDK_ROOT_PARENT();
+	rootwindow = gdk_get_default_root_window();
 	if (!rootwindow) return TRUE;
 
-	gdkvisual = gdk_window_get_visual(rootwindow);
+	gdkvisual = gdk_drawable_get_visual(rootwindow);
 	if (gdkvisual != gdk_visual_get_system()) return TRUE;
 
 	if (debug_mode) printf("root window capture: %d, %d (%d x %d) to %d, %d\n", screen_x, screen_y, w, h, x, y);
@@ -361,9 +366,9 @@ gint util_pixbuf_fill_from_root_window(GdkPixbuf *pb, gint x, gint y, gint get_a
 					clear_window = FALSE;
 
 					if (!pp) pp = gdk_pixmap_foreign_new(p);
-					cmap = gdk_window_get_colormap(rootwindow);
+					cmap = gdk_drawable_get_colormap(rootwindow);
 
-					gdk_window_get_size(pp, &p_w, &p_h);
+					gdk_drawable_get_size(pp, &p_w, &p_h);
 
 					if (p_w < screen_x + w || p_h < screen_y + h)
 						{
