@@ -135,7 +135,7 @@ void ui_widget_sync_back(UIData *ui, WidgetData *wd)
 
 	if (wd->od && wd->od->func_back)
 		{
-		wd->od->func_back(wd->widget, ui->skin->pixbuf);
+		wd->od->func_back(wd->widget, ui->skin->overlay);
 		}
 }
 
@@ -530,6 +530,8 @@ WidgetObjectData *ui_widget_type_new(const gchar *description)
 	od->type = widget_type_count;
 	widget_type_count++;
 
+	od->priority = UI_WIDGET_PRIORITY_NORMAL;
+
 	od->description = g_strdup(description);
 	od->is_visible = TRUE;
 
