@@ -372,6 +372,7 @@ void pixbuf_copy_fill_alpha_offset(GdkPixbuf *src, gint sx, gint sy, gint sw, gi
 }
 
 static void _pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
+				     gint dx, gint dy, gint dw, gint dh,
 				     gint border_left, gint left_stretch,
 				     gint border_right, gint right_stretch,
 				     gint border_top, gint top_stretch,
@@ -380,7 +381,6 @@ static void _pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
 				     gint apply_alpha, gint alpha_modifier, gint alpha_too)
 {
 	gint sw, sh;
-	gint dw, dh;
 	gint n, m;
 
 	if (!src || !dest) return;
@@ -388,24 +388,21 @@ static void _pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
 	sw = gdk_pixbuf_get_width(src);
 	sh = gdk_pixbuf_get_height(src);
 
-	dw = gdk_pixbuf_get_width(dest);
-	dh = gdk_pixbuf_get_height(dest);
-
 	/* corners */
 	_pixbuf_copy_area_alpha(src, 0, 0,
-				dest, 0, 0,
+				dest, dx, dy,
 				border_left, border_top,
 				apply_alpha, alpha_modifier, alpha_too);
 	_pixbuf_copy_area_alpha(src, sw - border_right, 0,
-				dest, dw - border_right, 0,
+				dest, dx + dw - border_right, dy,
 				border_right, border_top,
 				apply_alpha, alpha_modifier, alpha_too);
 	_pixbuf_copy_area_alpha(src, 0, sh - border_bottom,
-				dest, 0, dh - border_bottom,
+				dest, dx, dy + dh - border_bottom,
 				border_left, border_bottom,
 				apply_alpha, alpha_modifier, alpha_too);
 	_pixbuf_copy_area_alpha(src, sw - border_right, sh - border_bottom,
-				dest, dw - border_right, dh - border_bottom,
+				dest, dx + dw - border_right, dy + dh - border_bottom,
 				border_right, border_bottom,
 				apply_alpha, alpha_modifier, alpha_too);
 
@@ -414,30 +411,31 @@ static void _pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
 	m = border_left + border_right;	/* horz borders tot. */
 
 	_pixbuf_copy_fill_alpha(src, 0, border_top, border_left, sh - n,
-				dest, 0, border_top, border_left, dh - n,
+				dest, dx, dy + border_top, border_left, dh - n,
 				left_stretch,
 				apply_alpha, alpha_modifier, alpha_too, 0, 0);
 	_pixbuf_copy_fill_alpha(src, sw - border_right, border_top, border_right, sh - n,
-				dest, dw - border_right, border_top, border_right, dh - n,
+				dest, dx + dw - border_right, dy + border_top, border_right, dh - n,
 				right_stretch,
 				apply_alpha, alpha_modifier, alpha_too, 0, 0);
 	_pixbuf_copy_fill_alpha(src, border_left, 0, sw - m, border_top,
-				dest, border_left, 0, dw - m, border_top,
+				dest, dx + border_left, dy, dw - m, border_top,
 				top_stretch,
 				apply_alpha, alpha_modifier, alpha_too, 0, 0);
 	_pixbuf_copy_fill_alpha(src, border_left, sh - border_bottom, sw - m, border_bottom,
-				dest, border_left, dh - border_bottom, dw - m, border_bottom,
+				dest, dx + border_left, dy + dh - border_bottom, dw - m, border_bottom,
 				bottom_stretch,
 				apply_alpha, alpha_modifier, alpha_too, 0, 0);
 
 	/* center field */
 	_pixbuf_copy_fill_alpha(src, border_left, border_top, sw - m, sh - n,
-				dest, border_left, border_top, dw - m, dh - n,
+				dest, dx + border_left, dy + border_top, dw - m, dh - n,
 				stretch_center,
 				apply_alpha, alpha_modifier, alpha_too, 0, 0);
 }
 
 void pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
+			     gint x, gint y, gint width, gint height,
 			     gint border_left, gint left_stretch,
 			     gint border_right, gint right_stretch,
 			     gint border_top, gint top_stretch,
@@ -445,6 +443,7 @@ void pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
 			     gint stretch_center, gint alpha_too)
 {
 	_pixbuf_copy_fill_border(src, dest,
+				 x, y, width, height,
 				 border_left, left_stretch,
 				 border_right, right_stretch,
 				 border_top, top_stretch,
@@ -454,6 +453,7 @@ void pixbuf_copy_fill_border(GdkPixbuf *src, GdkPixbuf *dest,
 }
 
 void pixbuf_copy_fill_border_alpha(GdkPixbuf *src, GdkPixbuf *dest,
+				   gint x, gint y, gint width, gint height,
 				   gint border_left, gint left_stretch,
 				   gint border_right, gint right_stretch,
 				   gint border_top, gint top_stretch,
@@ -462,6 +462,7 @@ void pixbuf_copy_fill_border_alpha(GdkPixbuf *src, GdkPixbuf *dest,
 				   gint alpha_modifier)
 {
 	_pixbuf_copy_fill_border(src, dest,
+				 x, y, width, height,
 				 border_left, left_stretch,
 				 border_right, right_stretch,
 				 border_top, top_stretch,
@@ -1160,6 +1161,83 @@ void pixbuf_draw_rect_fill(GdkPixbuf *pb,
 		}
 }
 
+void pixbuf_draw_rect(GdkPixbuf *pb,
+		      gint x, gint y, gint w, gint h,
+		      gint r, gint g, gint b, gint a,
+		      gint left, gint right, gint top, gint bottom)
+{
+	pixbuf_draw_rect_fill(pb, x + left, y, w - left - right, top,
+			      r, g, b ,a);
+	pixbuf_draw_rect_fill(pb, x + w - right, y, right, h,
+			      r, g, b ,a);
+	pixbuf_draw_rect_fill(pb, x + left, y + h - bottom, w - left - right, bottom,
+			      r, g, b ,a);
+	pixbuf_draw_rect_fill(pb, x, y, left, h,
+			      r, g, b ,a);
+}
+
+guchar pixel_shift(gint p, gint saturation, gint adjustment, gint strength)
+{
+	gint t;
+
+	if (adjustment >= 128)
+		{
+		t = CLAMP(saturation + saturation * (adjustment - 128) / 127, 0, 255);
+		}
+	else
+		{
+		t = saturation * adjustment / 128;
+		}
+	p = (p * (255-strength) + t * strength) / 255;
+                                                                                                                        
+	return (guchar)p;
+}
+
+/*
+ * Shifts color hue in region, attempting to maintain intensity.
+ */
+void pixbuf_draw_rect_shift(GdkPixbuf *pb,
+			    gint x, gint y, gint w, gint h,
+			    gint r, gint g, gint b, gint strength)
+{
+	gint p_alpha;
+	gint pw, ph, prs;
+	guchar *p_pix;
+	guchar *pp;
+	gint i, j;
+
+	if (!pb) return;
+
+	pw = gdk_pixbuf_get_width(pb);
+	ph = gdk_pixbuf_get_height(pb);
+
+	if (x < 0 || x + w > pw) return;
+	if (y < 0 || y + h > ph) return;
+
+	p_alpha = gdk_pixbuf_get_has_alpha(pb);
+	prs = gdk_pixbuf_get_rowstride(pb);
+	p_pix = gdk_pixbuf_get_pixels(pb);
+
+	for (i = 0; i < h; i++)
+		{
+		pp = p_pix + (y + i) * prs + (x * (p_alpha ? 4 : 3));
+		for (j = 0; j < w; j++)
+			{
+			gint s;
+
+			s = (pp[0] + pp[1] + pp[2]) / 3;
+
+			*pp = pixel_shift(*pp, s, r, strength);
+                        pp++;
+			*pp = pixel_shift(*pp, s, g, strength);
+                        pp++;
+			*pp = pixel_shift(*pp, s, b, strength);
+			pp++;
+			if (p_alpha) pp++;
+			}
+		}
+}
+
 static guchar pixel_adjust(gint p, gint a)
 {
 	p += a;
