@@ -197,44 +197,80 @@ static gint key_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 			case '~': case '`':
 				btn_edit_skin_pressed(ui);
 				break;
+			case GDK_F1:
+			case GDK_Help:
+				help_window_show("documentation");
+				break;
+
+	/*
+	 * Sorry about this #ifdef mess, but the XF86keysym.h file seems to change
+	 * on almost every Xfree release - older versions do not have some of these.
+	 */
 #ifdef HAVE_XF86_KEYSYMS
+
+#ifdef XF86XK_AudioLowerVolume
 			case XF86XK_AudioLowerVolume:
 				btn_volume_down_pressed();
 				btn_volume_released();
 				break;
+#endif
+#ifdef XF86XK_AudioMute
 			case XF86XK_AudioMute:
 				/* FIXME: gqmpeg has no mute facility */
 				btn_mixer_pressed();
 				break;
+#endif
+#ifdef XF86XK_AudioRaiseVolume
 			case XF86XK_AudioRaiseVolume:
 				btn_volume_up_pressed();
 				btn_volume_released();
 				break;
+#endif
+#ifdef XF86XK_AudioPlay
 			case XF86XK_AudioPlay:
 				btn_play_pressed();
 				break;
+#endif
+#ifdef XF86XK_AudioStop
 			case XF86XK_AudioStop:
 				btn_stop_pressed();
 				break;
+#endif
+#ifdef XF86XK_AudioPrev
 			case XF86XK_AudioPrev:
 				btn_prev_down();
 				btn_prev_pressed();
 				break;
+#endif
+#ifdef XF86XK_AudioNext
 			case XF86XK_AudioNext:
 				btn_next_down();
 				btn_next_pressed();
 				break;
+#endif
+#ifdef XF86XK_AudioPause
 			case XF86XK_AudioPause:
 				btn_pause_pressed();
 				break;
+#endif
+#if defined(XF86XK_AudioMedia) || defined(XF86XK_Eject)
+  #ifdef XF86XK_AudioMedia
 			case XF86XK_AudioMedia:
+  #endif
+  #ifdef XF86XK_Eject
 			case XF86XK_Eject:
+  #endif
 				playlist_window_toggle();
 				break;
+#endif
+#ifdef XF86XK_OpenURL
 			case XF86XK_OpenURL:
 				btn_load_file_pressed();
 				break;
 #endif
+
+#endif /* HAVE_XF86_KEYSYMS */
+
 			default:
 				ret = FALSE;
 				break;
@@ -317,14 +353,14 @@ static void main_window_new_subwindow_cb(UIData *child, const gchar *key, gpoint
 {
 	const gchar *title;
 
-	gtk_signal_connect(GTK_OBJECT(child->window), "delete_event",
-			   GTK_SIGNAL_FUNC(subwindow_delete_cb), child);
-	gtk_signal_connect(GTK_OBJECT(child->display), "key_press_event",
-			   GTK_SIGNAL_FUNC(key_pressed), child);
+	g_signal_connect(G_OBJECT(child->window), "delete_event",
+			 G_CALLBACK(subwindow_delete_cb), child);
+	g_signal_connect(G_OBJECT(child->display), "key_press_event",
+			 G_CALLBACK(key_pressed), child);
 
 	if (!key) return;
 
-	ui_set_icon(child, (const char **)gqmpeg_icon_xpm, NULL);
+	ui_set_icon(child, (const char **)gqmpeg_icon_xpm, NULL, NULL);
 
 	if (strstr(key, "list") || strstr(key, "playlist"))
 		{
@@ -356,14 +392,14 @@ UIData *main_window_create(const gchar *skin_path)
 
 	ui = ui_new("GQmpeg", "gqmpeg", wm_decorations, "GQmpeg");
 	if (dock_mode) ui_moveable_set(ui, FALSE);
-	ui_set_icon(ui, (const char **)gqmpeg_icon_xpm, NULL);
+	ui_set_icon(ui, (const char **)gqmpeg_icon_xpm, NULL, NULL);
 
 	ui_set_skin_callback(ui, skin_load_default_cb, NULL);
 
-	gtk_signal_connect(GTK_OBJECT(ui->window), "delete_event",
-			   GTK_SIGNAL_FUNC(destroy), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->display), "key_press_event",
-			   GTK_SIGNAL_FUNC(key_pressed), ui);
+	g_signal_connect(G_OBJECT(ui->window), "delete_event",
+			 G_CALLBACK(destroy), ui);
+	g_signal_connect(G_OBJECT(ui->display), "key_press_event",
+			 G_CALLBACK(key_pressed), ui);
 
 	ui_set_mouse_callback(ui, main_window_mouse_cb, NULL);
 	ui_set_new_window_callback(ui, main_window_new_subwindow_cb, NULL);
